@@ -12,6 +12,7 @@
 #define NO_IMPORT_ARRAY
 #include <numpy/arrayobject.h>
 #include <stdlib.h>
+#include <stdbool.h>
 
 /* If strict ANSI, then some useful macros are not defined */
 #if defined(__STRICT_ANSI__) && !defined(__DARWIN_UNIX03)
@@ -24,14 +25,6 @@
    typedef double complex double_complex;
 #endif
 
-//#ifdef NO_C99_COMPLEX
-typedef int bool;
-#define true 1
-#define false 0
-//#else
-//#include <stdbool.h>
-//#endif
-
 static inline void* gpaw_malloc(size_t n)
 {
   void* p = malloc(n);
