@@ -41,9 +41,7 @@ qsfdtd = QSFDTD(classical_material=classical_material,
                 spacings=[2.0, 0.5],
                 remove_moments=(1, 1))
 
-energy = qsfdtd.ground_state('gs.gpw',
-                             nbands=1,
-                             symmetry='off')
+energy = qsfdtd.ground_state('gs.gpw', mode='fd', nbands=1, symmetry='off')
 
 qsfdtd.time_propagation('gs.gpw',
                         kick_strength=[0.001, 0.000, 0.000],
@@ -66,7 +64,7 @@ qsfdtd = QSFDTD(classical_material=classical_material,
                 spacings=[2.0, 0.5],
                 remove_moments=(1, 1))
 
-energy = qsfdtd.ground_state('gs.gpw', nbands=-1)
+energy = qsfdtd.ground_state('gs.gpw', mode='fd', nbands=-1, symmetry='off')
 
 qsfdtd.time_propagation('gs.gpw',
                         kick_strength=[0.001, 0.000, 0.000],
@@ -88,7 +86,7 @@ qsfdtd = QSFDTD(classical_material=classical_material,
                 spacings=[2.0, 0.5],
                 remove_moments=(1, 1))
 
-energy = qsfdtd.ground_state('gs.gpw', nbands=-1)
+energy = qsfdtd.ground_state('gs.gpw', mode='fd', nbands=-1, symmetry='off')
 
 qsfdtd.time_propagation('gs.gpw',
                         kick_strength=[0.001, 0.000, 0.000],
