@@ -4,7 +4,7 @@ from ase.units import Hartree
 from gpaw import GPAW, setup_paths
 from gpaw.mpi import world
 from gpaw.occupations import FermiDirac
-from gpaw.test import equal, gen
+from gpaw.test import gen
 from gpaw.eigensolvers import RMMDIIS
 from gpaw.cluster import Cluster
 from gpaw.lrtddft import LrTDDFT
@@ -30,7 +30,7 @@ mol.calc = calc
 mol.get_potential_energy()
 (eps_homo, eps_lumo) = calc.get_homo_lumo()
 e_ex = eps_lumo - eps_homo
-equal(e_singlet, e_ex, 0.15)
+assert abs(e_singlet - e_ex) < 0.15
 calc.write('NaCl.gpw')
 
 lr = LrTDDFT(calc, txt='LCY_TDDFT_NaCl.log',
@@ -40,4 +40,4 @@ if world.rank == 0:
     lr2 = LrTDDFT.read('LCY_TDDFT_NaCl.ex.gz')
     lr2.diagonalize()
     ex_lr = lr2[1].get_energy() * Hartree
-    equal(e_singlet_lr, e_singlet, 0.05)
+    assert abs(e_singlet_lr - e_singlet) < 0.05
