@@ -1,3 +1,3 @@
 # creates: N.LDA
 from gpaw.test import gen
-gen('N')
+gen('N', write_xml=True)
