@@ -1,7 +1,8 @@
-# web-page: extrapolate.png
+# web-page: extrapolate.png, N2-data.csv
 import numpy as np
 import matplotlib.pyplot as plt
 from gpaw.utilities.extrapolate import extrapolate
+from pathlib import Path
 
 a = np.loadtxt('rpa_N2.dat')
 ext, A, B, sigma = extrapolate(a[:, 0], a[:, 1], reg=3, plot=False)
@@ -15,5 +16,15 @@ plt.axis([0., 150**(-1.5), None, -4.])
 plt.xlabel('Cutoff energy [eV]', fontsize=18)
 plt.ylabel('RPA correlation energy [eV]', fontsize=18)
 plt.legend(loc='lower right')
-# show()
 plt.savefig('extrapolate.png')
+
+pbe, hf = (-float(line.split()[1])
+           for line in Path('PBE_HF.dat').read_text().splitlines())
+rpa = -A
+Path('N2-data.csv').write_text(
+    'PBE, HF, RPA, HF+RPA, Experimental\n'
+    f'{pbe:.2f}, {hf:.2f}, {rpa:.2f}, {hf + rpa:.2f}, 9.89\n')
+
+assert abs(pbe - 10.600) < 0.01
+assert abs(hf - 4.840) < 0.01
+assert abs(rpa - 4.912) < 0.01
