@@ -11,7 +11,7 @@ data = np.zeros((5, 6))
 
 for i, domega0 in enumerate([0.01, 0.02, 0.03, 0.04, 0.05]):
     for j, omega2 in enumerate([1, 5, 10, 15, 20, 25]):
-        path = f'C_g0w0_domega0_{domega0}_omega2_{omega2}_results.pckl'
+        path = f'C_g0w0_domega0_{domega0}_omega2_{omega2}_results_GW.pckl'
         results = pickle.load(open(path, 'rb'))
 
         data[i, j] = results['qp'][0, 0, 1] - results['qp'][0, 0, 0]
