@@ -9,7 +9,7 @@ atoms = Atoms(symbols='Na2',
 atoms.center(vacuum=6.0)
 
 # Standard ground state calculation with empty states
-calc = GPAW(nbands=100, h=0.4, setups={'Na': '1'})
+calc = GPAW(mode='fd', nbands=100, h=0.4, setups={'Na': '1'})
 atoms.calc = calc
 energy = atoms.get_potential_energy()
 
