@@ -6,7 +6,8 @@ from gpaw import GPAW
 atoms = read('r-methyloxirane.xyz')
 atoms.center(vacuum=8)
 
-calc = GPAW(h=0.2,
+calc = GPAW(mode='fd',
+            h=0.2,
             nbands=14,
             xc='LDA',
             poissonsolver={'name': 'MomentCorrectionPoissonSolver',
