@@ -10,7 +10,7 @@ atoms = Cluster(molecule('H2O'))
 atoms.minimal_box(4, h=h)
 
 # relax the molecule
-calc = GPAW(xc='PBE', h=h, occupations=FermiDirac(width=0.1))
+calc = GPAW(mode='fd', xc='PBE', h=h, occupations=FermiDirac(width=0.1))
 atoms.calc = calc
 
 dyn = optimize.FIRE(atoms)
