@@ -9,7 +9,7 @@ xc = 'PBE'
 atoms = Cluster('relaxed.traj')
 atoms.minimal_box(4., h=h)
 
-atoms.calc = GPAW(xc=xc, h=h,
+atoms.calc = GPAW(mode='fd', xc=xc, h=h,
                   occupations=FermiDirac(width=0.1),
                   symmetry={'point_group': False})
 atoms.get_potential_energy()
