@@ -1,7 +1,7 @@
 from gpaw import GPAW
 from ase.build import molecule
 
-calc = GPAW()
+calc = GPAW(mode='fd')
 mol = molecule('C6H6', calculator=calc)
 mol.center(vacuum=5)
 E = mol.get_potential_energy()
