@@ -7,8 +7,10 @@ import contextlib
 from pathlib import Path
 from typing import List, Dict, Union, Any, TYPE_CHECKING
 
-__version__ = '23.9.1'
+
+__version__ = '24.1.0'
 __ase_version_required__ = '3.22.1'
+
 __all__ = ['GPAW',
            'Mixer', 'MixerSum', 'MixerDif', 'MixerSum2',
            'MixerFull',
@@ -41,35 +43,17 @@ def disable_dry_run():
     dry_run = size
 
 
+def get_scipy_version():
+    import scipy
+    # This is in a function because we don't like to have the scipy
+    # import at module level
+    return [int(x) for x in scipy.__version__.split('.')[:2]]
+
+
 if 'OMP_NUM_THREADS' not in os.environ:
     os.environ['OMP_NUM_THREADS'] = '1'
 
 
-from gpaw.broadcast_imports import broadcast_imports  # noqa
-
-with broadcast_imports:
-    import os
-    import runpy
-    import warnings
-    from argparse import ArgumentParser, REMAINDER, RawDescriptionHelpFormatter
-
-    # With gpaw-python BLAS symbols are in global scope and we need to
-    # ensure that NumPy and SciPy use symbols from their own dependencies
-    if is_gpaw_python:
-        old_dlopen_flags = sys.getdlopenflags()
-        sys.setdlopenflags(old_dlopen_flags | os.RTLD_DEEPBIND)
-    import numpy as np
-    import scipy.linalg  # noqa: F401
-    if is_gpaw_python:
-        sys.setdlopenflags(old_dlopen_flags)
-    import _gpaw
-
-SCIPY_VERSION = [int(x) for x in scipy.__version__.split('.')[:2]]
-
-if getattr(_gpaw, 'version', 0) != 4:
-    raise ImportError('Please recompile GPAW''s C-extensions!')
-
-
 class ConvergenceError(Exception):
     pass
 
@@ -91,14 +75,35 @@ class BadParallelization(Exception):
     pass
 
 
-libraries: Dict[str, str] = {}
-if hasattr(_gpaw, 'lxcXCFunctional'):
-    libraries['libxc'] = getattr(_gpaw, 'libxc_version', '2.x.y')
-else:
-    libraries['libxc'] = ''
+def get_libraries():
+    import _gpaw
+    libraries: Dict[str, str] = {}
+    if hasattr(_gpaw, 'lxcXCFunctional'):
+        libraries['libxc'] = getattr(_gpaw, 'libxc_version', '2.x.y')
+    else:
+        libraries['libxc'] = ''
+    return libraries
 
 
 def parse_arguments(argv):
+    from argparse import (ArgumentParser, REMAINDER,
+                          RawDescriptionHelpFormatter)
+    import warnings
+
+    # With gpaw-python BLAS symbols are in global scope and we need to
+    # ensure that NumPy and SciPy use symbols from their own dependencies
+    if is_gpaw_python:
+        old_dlopen_flags = sys.getdlopenflags()
+        sys.setdlopenflags(old_dlopen_flags | os.RTLD_DEEPBIND)
+
+    if is_gpaw_python:
+        sys.setdlopenflags(old_dlopen_flags)
+
+    import _gpaw
+
+    if getattr(_gpaw, 'version', 0) != 4:
+        raise ImportError('Please recompile GPAW''s C-extensions!')
+
     version = sys.version.replace('\n', '')
     p = ArgumentParser(usage='%(prog)s [OPTION ...] [-c | -m] SCRIPT'
                        ' [ARG ...]',
@@ -145,8 +150,80 @@ def parse_arguments(argv):
     return args
 
 
+def __getattr__(attr: str) -> Any:
+    """
+    Implement the lazy importing of classes in submodules."""
+
+    import importlib
+
+    try:
+        import_target = all_lazy_imports[attr]
+    except KeyError:
+        raise AttributeError(
+            f'{__getattr__.__module__}: no attribute named `.{attr!r}`'
+        ) from None
+
+    module, sep, target = import_target.rpartition('.')
+    assert module and all(chunk.isidentifier() for chunk in module.split('.'))
+    assert sep
+    assert target.isidentifier()
+    return getattr(importlib.import_module(module), target)
+
+
+def __dir__() -> List[str]:
+    """
+    Get the normally-present module attributes and the lazily-imported objects.
+    """
+    return [*globals(), *all_lazy_imports]
+
+
+all_lazy_imports = dict(
+    OldGPAW='gpaw.calculator.GPAW',
+    Mixer='gpaw.mixer.Mixer',
+    MixerSum='gpaw.mixer.MixerSum',
+    MixerDif='gpaw.mixer.MixerDif',
+    MixerSum2='gpaw.mixer.MixerSum2',
+    MixerFull='gpaw.mixer.MixerFull',
+
+    Davidson='gpaw.eigensolvers.Davidson',
+    RMMDIIS='gpaw.eigensolvers.RMMDIIS',
+    CG='gpaw.eigensolvers.CG',
+    DirectLCAO='gpaw.eigensolvers.DirectLCAO',
+
+    PoissonSolver='gpaw.poisson.PoissonSolver',
+    FermiDirac='gpaw.occupations.FermiDirac',
+    MethfesselPaxton='gpaw.occupations.MethfesselPaxton',
+    MarzariVanderbilt='gpaw.occupations.MarzariVanderbilt',
+    FD='gpaw.wavefunctions.fd.FD',
+    LCAO='gpaw.wavefunctions.lcao.LCAO',
+    PW='gpaw.wavefunctions.pw.PW',
+)
+
+
+class BroadcastImports:
+    def __enter__(self):
+        from gpaw._broadcast_imports import broadcast_imports
+        self._context = broadcast_imports
+        return self._context.__enter__()
+
+    def __exit__(self, *args):
+        self._context.__exit__(*args)
+
+
+broadcast_imports = BroadcastImports()
+
+
 def main():
-    gpaw_args = parse_arguments(sys.argv)
+    with broadcast_imports:
+        import runpy
+
+        # Apparently we need the scipy.linalg import for compatibility?
+        import scipy.linalg  # noqa: F401
+
+        for attr in all_lazy_imports:
+            __getattr__(attr)
+
+        gpaw_args = parse_arguments(sys.argv)
     # The normal Python interpreter puts . in sys.path, so we also do that:
     sys.path.insert(0, '.')
     # Stacktraces can be shortened by running script with
@@ -163,6 +240,7 @@ def main():
 
 
 if debug:
+    import numpy as np
     np.seterr(over='raise', divide='raise', invalid='raise', under='ignore')
     oldempty = np.empty
     oldempty_like = np.empty_like
@@ -187,27 +265,18 @@ if debug:
     np.empty_like = empty_like
 
 
-with broadcast_imports:
-    from gpaw.calculator import GPAW as OldGPAW
-    from gpaw.mixer import Mixer, MixerSum, MixerDif, MixerSum2, \
-        MixerFull
-    from gpaw.eigensolvers import Davidson, RMMDIIS, CG, DirectLCAO
-    from gpaw.poisson import PoissonSolver
-    from gpaw.occupations import (FermiDirac, MethfesselPaxton,
-                                  MarzariVanderbilt)
-    from gpaw.wavefunctions.lcao import LCAO
-    from gpaw.wavefunctions.pw import PW
-    from gpaw.wavefunctions.fd import FD
-
-
 def GPAW(*args, **kwargs) -> Any:
     if os.environ.get('GPAW_NEW'):
         from gpaw.new.ase_interface import GPAW as NewGPAW
         return NewGPAW(*args, **kwargs)
+
+    from gpaw.calculator import GPAW as OldGPAW
     return OldGPAW(*args, **kwargs)
 
 
-def restart(filename, Class=GPAW, **kwargs):
+def restart(filename, Class=None, **kwargs):
+    if Class is None:
+        from gpaw import GPAW as Class
     calc = Class(filename, **kwargs)
     atoms = calc.get_atoms()
     return atoms, calc
@@ -240,5 +309,7 @@ initialize_data_paths()
 
 
 def RMM_DIIS(*args, **kwargs):
+    import warnings
+    from gpaw import RMMDIIS
     warnings.warn('Please use RMMDIIS instead of RMM_DIIS')
     return RMMDIIS(*args, **kwargs)
