@@ -78,9 +78,19 @@ class DistributedArrays(Generic[DomainType]):
     def copy(self):
         return self.new(data=self.data.copy())
 
+    def sanity_check(self) -> None:
+        """Sanity check."""
+        pass
+
     def __getitem__(self, index):
         raise NotImplementedError
 
+    def __bool__(self):
+        raise ValueError
+
+    def __len__(self):
+        return self.dims[0]
+
     def __iter__(self):
         for index in range(self.dims[0]):
             yield self[index]
@@ -236,8 +246,9 @@ def _parallel_me(psit1_nX: DistributedArrays,
 
     n_r = [min(r * B, nbands) for r in range(comm.size + 1)]
 
-    buf1_nX = psit1_nX.desc.empty(B)
-    buf2_nX = psit1_nX.desc.empty(B)
+    xp = psit1_nX.xp
+    buf1_nX = psit1_nX.desc.empty(B, xp=xp)
+    buf2_nX = psit1_nX.desc.empty(B, xp=xp)
     psit_nX = psit2_nX
 
     for shift in range(comm.size):
@@ -287,9 +298,10 @@ def _parallel_me_sym(psit1_nX: DistributedArrays,
     mynbands_r = [n_r[r + 1] - n_r[r] for r in range(comm.size)]
     assert mynbands_r[comm.rank] == mynbands
 
+    xp = psit1_nX.xp
     psit2_nX = psit1_nX
-    buf1_nX = psit1_nX.desc.empty(B)
-    buf2_nX = psit1_nX.desc.empty(B)
+    buf1_nX = psit1_nX.desc.empty(B, xp=xp)
+    buf2_nX = psit1_nX.desc.empty(B, xp=xp)
     half = comm.size // 2
 
     for shift in range(half + 1):
@@ -346,7 +358,7 @@ def _parallel_me_sym(psit1_nX: DistributedArrays,
                 n1 = n_r[row]
                 n2 = n_r[row + 1]
                 if mynbands > 0 and n2 > n1:
-                    block = np.empty((mynbands, n2 - n1), M_nn.dtype)
+                    block = xp.empty((mynbands, n2 - n1), M_nn.dtype)
                     blocks.append((n1, n2, block))
                     requests.append(comm.receive(block, row, 12, False))
 
