@@ -3,13 +3,12 @@ from __future__ import annotations
 
 from types import ModuleType
 from typing import Dict, Tuple
-
 import _gpaw
 import numpy as np
 import scipy.linalg as sla
 
 import gpaw.utilities.blas as blas
-from gpaw import debug, SCIPY_VERSION
+from gpaw import debug, get_scipy_version
 from gpaw.gpu import cupy as cp, cupy_eigh
 from gpaw.mpi import MPIComm, _Communicator, serial_comm
 from gpaw.typing import Array1D, ArrayLike1D, ArrayLike2D, Array2D
@@ -118,7 +117,7 @@ class Matrix:
         if data is None:
             self.data = self.xp.empty(dist.shape, self.dtype)
         else:
-            assert data.shape == dist.shape, (data.shape, dist.shape)
+            assert data.shape == dist.shape, (data.shape, dist.shape, dist)
             self.data = data
 
     def __repr__(self):
@@ -178,17 +177,6 @@ class Matrix:
         elif not isinstance(out, Matrix):
             out = out.matrix
 
-        if 0:  # dist.comm.size > 1:
-            # Special cases that don't need scalapack - most likely also
-            # faster:
-            if alpha == 1.0 and opa == 'N' and opb == 'N':
-                return fastmmm(A, B, out, beta)
-            if alpha == 1.0 and beta == 1.0 and opa == 'N' and opb == 'C':
-                if symmetric:
-                    return fastmmm2(A, B, out)
-                else:
-                    return fastmmm2notsym(A, B, out)
-
         dist.multiply(alpha, A, opa, B, opb, beta, out, symmetric=symmetric)
         return out
 
@@ -318,7 +306,7 @@ class Matrix:
                                     overwrite_a=True,
                                     check_finite=debug)
             else:
-                self.tril2full()
+                S.tril2full()
                 L_nn = cp.linalg.cholesky(S.data)
                 S.data[:] = cp.linalg.inv(L_nn)
 
@@ -361,12 +349,12 @@ class Matrix:
             if S is not None:
                 S0 = S
                 S = S0.new(dist=dist)
-                self.redist(S)
+                S0.redist(S)
         else:
             assert self.dist.comm.size == slcomm.size
             H = self
 
-        eps = np.empty(H.shape[0])
+        eps = self.xp.empty(H.shape[0])
 
         if rows * columns == 1:
             if self.dist.comm.rank == 0:
@@ -377,16 +365,17 @@ class Matrix:
                 if S is None:
                     if self.xp is not np:
                         assert isinstance(H.data, cp.ndarray)
-                        eps, H.data.T[:] = cupy_eigh(H.data, UPLO='L')
-                        return eps
-                    eps[:], H.data.T[:] = sla.eigh(
-                        H.data,
-                        lower=True,
-                        overwrite_a=True,
-                        check_finite=debug,
-                        driver='evx' if H.data.size == 1 else 'evd')
+                        eps[:], H.data.T[:] = cupy_eigh(H.data, UPLO='L')
+                    else:
+                        eps[:], H.data.T[:] = sla.eigh(
+                            H.data,
+                            lower=True,
+                            overwrite_a=True,
+                            check_finite=debug,
+                            driver='evx' if H.data.size == 1 else 'evd')
                 else:
                     if self.xp is cp:
+                        assert self.dist.comm.size == 1
                         S.invcholesky()
                         self.tril2full()
                         eigs = self.eighg(S)
@@ -468,7 +457,7 @@ class Matrix:
                 blas.mmm(1.0, L_MM, 'N', H.data, 'N', 0.0, tmp_MM)
                 blas.r2k(0.5, tmp_MM, L_MM, 0.0, H.data)
                 # Ht_MM = L_MM @ H.data @ L_MM.conj().T
-                if SCIPY_VERSION >= [1, 9]:
+                if get_scipy_version() >= [1, 9]:
                     driver = 'evx' if M == 1 else 'evd'
                 else:
                     driver = None
@@ -561,6 +550,41 @@ def _matrix(M):
     return _matrix(M.matrix)
 
 
+def redist(dist1, M1, dist2, M2, context):
+    _gpaw.scalapack_redist(dist1.desc, dist2.desc,
+                           M1, M2,
+                           dist1.desc[2], dist1.desc[3],
+                           1, 1, 1, 1,  # 1-indexing
+                           context, 'G')
+
+
+def create_distribution(M: int,
+                        N: int,
+                        comm: MPIComm | None = None,
+                        r: int = 1,
+                        c: int = 1,
+                        b: int | None = None,
+                        xp=None) -> MatrixDistribution:
+    if xp is cp:
+        assert b is None
+        if r == 1 and c == 1:
+            pass  # comm = None
+        comm = comm or serial_comm
+        return CuPyDistribution(M, N, comm,
+                                r if r != -1 else comm.size,
+                                c if c != -1 else comm.size,
+                                b)
+
+    if comm is None or comm.size == 1:
+        assert r == 1 and abs(c) == 1 or c == 1 and abs(r) == 1
+        return NoDistribution(M, N)
+
+    return BLACSDistribution(M, N, comm,
+                             r if r != -1 else comm.size,
+                             c if c != -1 else comm.size,
+                             b)
+
+
 class MatrixDistribution:
     comm: MPIComm
     rows: int
@@ -630,6 +654,7 @@ class NoDistribution(MatrixDistribution):
                         return
                     blas.r2k(0.5 * alpha, a.data, b.data, beta, c.data)
             else:
+                1 / 0
                 assert opa == 'C' and opb == 'N'
                 assert a is not b
                 blas.r2k(0.5 * alpha, a.data, b.data, beta, c.data, 'n')
@@ -647,6 +672,7 @@ class BLACSDistribution(MatrixDistribution):
         self.columns = c
         self.blocksize = b
         self.full_shape = (M, N)
+        self.simple = False
 
         key = (comm, r, c)
         context = _global_blacs_context_store.get(key)
@@ -663,6 +689,7 @@ class BLACSDistribution(MatrixDistribution):
             if c == 1:
                 br = (M + r - 1) // r
                 bc = max(1, N)
+                self.simple = True
             elif r == 1:
                 br = M
                 bc = (N + c - 1) // c
@@ -703,6 +730,20 @@ class BLACSDistribution(MatrixDistribution):
                                  self.blocksize)
 
     def multiply(self, alpha, a, opa, b, opb, beta, c, symmetric):
+        if self.comm.size > 1:
+            ok = a.dist.simple and b.dist.simple and c.dist.simple
+            if ok:
+                # Special cases that don't need scalapack - most likely also
+                # faster:
+                if opa == 'N' and opb == 'N':
+                    return mmm_nn(a, b, c, alpha, beta, blas.mmm)
+                if opa == 'N' and opb == 'C':
+                    if symmetric:
+                        if beta == 1.0:
+                            return mmm_nc_sym(a, b, c, alpha, blas.mmm)
+                    else:
+                        return mmm_nc(a, b, c, alpha, beta, blas.mmm)
+
         if symmetric:
             assert opa == 'N'
             assert opb == 'C' or opb == 'T' and a.dtype == float
@@ -730,54 +771,55 @@ class BLACSDistribution(MatrixDistribution):
                              opb, opa)
 
 
-def redist(dist1, M1, dist2, M2, context):
-    _gpaw.scalapack_redist(dist1.desc, dist2.desc,
-                           M1, M2,
-                           dist1.desc[2], dist1.desc[3],
-                           1, 1, 1, 1,  # 1-indexing
-                           context, 'G')
-
-
-def create_distribution(M: int,
-                        N: int,
-                        comm: MPIComm | None = None,
-                        r: int = 1,
-                        c: int = 1,
-                        b: int | None = None,
-                        xp=None) -> MatrixDistribution:
-    if xp is cp:
-        return CuPyDistribution(M, N)
-
-    if comm is None or comm.size == 1:
-        assert r == 1 and abs(c) == 1 or c == 1 and abs(r) == 1
-        return NoDistribution(M, N)
-
-    return BLACSDistribution(M, N, comm,
-                             r if r != -1 else comm.size,
-                             c if c != -1 else comm.size,
-                             b)
+def cublas_mmm(alpha, a, opa, b, opb, beta, c):
+    if c.size == 0:
+        return
+    if a.size == 0 and beta == 1.0:
+        return
+    cp.cublas.gemm(opa.replace('C', 'H'), opb.replace('C', 'H'),
+                   a, b, c, alpha, beta)
 
 
 class CuPyDistribution(MatrixDistribution):
-    comm = serial_comm
-    rows = 1
-    columns = 1
-    blocksize = None
-
-    def __init__(self, M, N):
-        self.shape = (M, N)
+    def __init__(self, M, N, comm, r, c, b):
+        self.comm = comm
+        self.rows = r
+        self.columns = c
+        self.blocksize = b
         self.full_shape = (M, N)
+        # assert r == comm.size, (M, N, comm, r, c, b)
+        assert c == 1
+        br = (M + r - 1) // r
+        m = min((comm.rank + 1) * br, M) - min(comm.rank * br, M)
+        self.shape = (m, N)
 
     def __str__(self):
-        return 'CuPyDistribution({}x{})'.format(*self.shape)
+        M, N = self.full_shape
+        m, N = self.shape
+        return f'CuPyDistribution(global={M}x{N}, local={m}x{N})'
 
     def global_index(self, n):
+        1 / 0
         return n
 
     def new(self, M, N):
-        return CuPyDistribution(M, N)
+        return CuPyDistribution(M, N,
+                                self.comm,
+                                self.rows, self.columns,
+                                self.blocksize)
 
     def multiply(self, alpha, a, opa, b, opb, beta, c, *, symmetric=False):
+        if self.comm.size > 1:
+            if opa == 'N' and opb == 'N':
+                return mmm_nn(a, b, c, alpha, beta, cublas_mmm)
+            if opa == 'N' and opb == 'C':
+                if symmetric:
+                    if beta == 1.0:
+                        return mmm_nc_sym(a, b, c, alpha, cublas_mmm)
+                else:
+                    return mmm_nc(a, b, c, alpha, beta, cublas_mmm)
+            1 / 0
+
         if symmetric:
             if opa == 'N':
                 assert opb == 'C' or opb == 'T' and a.dtype == float
@@ -789,23 +831,20 @@ class CuPyDistribution(MatrixDistribution):
                 else:
                     if beta == 1.0 and a.shape[1] == 0:
                         return
-                    cp.cublas.gemm('N', 'H',
-                                   a.data, b.data, c.data,
-                                   0.5 * alpha, beta)
-                    cp.cublas.gemm('N', 'H',
-                                   b.data, a.data, c.data,
-                                   0.5 * alpha, 1.0)
+                    if c.data.size > 0:
+                        assert beta in [0.0, 1.0]
+                        cp.cublas.gemm('N', 'H',
+                                       a.data, b.data, c.data,
+                                       alpha, beta)
             else:
+                1 / 0
                 assert opa == 'C' and opb == 'N'
                 assert a is not b
                 raise NotImplementedError
                 blas.r2k(0.5 * alpha, a.data, b.data, beta, c.data, 'n')
 
         else:
-            cp.cublas.gemm(opa.replace('C', 'H'),
-                           opb.replace('C', 'H'),
-                           a.data, b.data, c.data,
-                           alpha, beta)
+            cublas_mmm(alpha, a.data, opa, b.data, opb, beta, c.data)
 
     def eighg(self, H, L):
         """
@@ -814,6 +853,7 @@ class CuPyDistribution(MatrixDistribution):
            ~      †   ~~   ~         †~
            H = LHL ,  HC = CΛ,  C = L C.
         """
+        assert self.comm.size == 1
         tmp = H.new()
         self.multiply(1.0, L, 'N', H, 'N', 0.0, tmp)
         self.multiply(1.0, tmp, 'N', L, 'C', 0.0, H, symmetric=True)
@@ -825,17 +865,24 @@ class CuPyDistribution(MatrixDistribution):
         return eig_M
 
 
-def fastmmm(m1, m2, m3, beta):
-    comm = m1.dist.comm
+def mmm_nn(m1, m2, m3, alpha, beta, mmm):
+    """Parallel matrix-matrix multiplication.
 
+    :::
+
+        m  <- αm m + βm
+         3      1 2    3
+    """
+    comm = m1.dist.comm
     buf1 = m2.data
+    xp = m1.xp
 
     N = m1.shape[0]
     n = (N + comm.size - 1) // comm.size
 
     for r in range(comm.size):
         if r == 0:
-            buf2 = np.empty((n, buf1.shape[1]), dtype=buf1.dtype)
+            buf2 = xp.empty((n, buf1.shape[1]), dtype=buf1.dtype)
 
         rrequest = None
         srequest = None
@@ -852,13 +899,12 @@ def fastmmm(m1, m2, m3, beta):
         r0 = (comm.rank + r) % comm.size
         n1 = min(r0 * n, N)
         n2 = min(n1 + n, N)
-        blas.mmm(1.0, m1.data[:, n1:n2], 'N', buf1[:n2 - n1], 'N',
-                 beta, m3.data)
+        mmm(alpha, m1.data[:, n1:n2], 'N', buf1[:n2 - n1], 'N', beta, m3.data)
 
         beta = 1.0
 
         if r == 0:
-            buf1 = np.empty_like(buf2)
+            buf1 = xp.empty_like(buf2)
 
         buf1, buf2 = buf2, buf1
 
@@ -870,20 +916,24 @@ def fastmmm(m1, m2, m3, beta):
     return m3
 
 
-def fastmmm2(a, b, out):
-    if a.comm:
-        assert b.comm is a.comm
-        if a.comm.size > 1:
-            assert out.comm == a.comm
-            assert out.state == 'a sum is needed'
+def mmm_nc_sym(a, b, out, alpha, mmm):
+    """Symmetric parallel matrix-matrix multiplication.
 
+    :::
+
+                †
+        c <- αab + c
+
+    Only lower half of c is updated.
+    """
     comm = a.dist.comm
     M, N = a.shape
     m = (M + comm.size - 1) // comm.size
     mym = len(a.data)
+    xp = a.xp
 
-    buf1 = np.empty((m, N), dtype=a.dtype)
-    buf2 = np.empty((m, N), dtype=a.dtype)
+    buf1 = xp.empty((m, N), dtype=a.dtype)
+    buf2 = xp.empty((m, N), dtype=a.dtype)
     half = comm.size // 2
     aa = a.data
     bb = b.data
@@ -908,11 +958,11 @@ def fastmmm2(a, b, out):
             m2 = min(m1 + m, M)
             if r == 0:
                 # symmmmmmmmmmmmmmmmmmmmmmetricccccccccccccccc
-                blas.mmm(1.0, aa, 'N', bb, 'C', 1.0, out.data[:, m1:m2])
+                mmm(alpha, aa, 'N', bb, 'C', 1.0, out.data[:, m1:m2])
             else:
                 beta = 1.0 if r <= comm.rank else 0.0
-                blas.mmm(1.0, aa, 'N', buf2[:m2 - m1], 'C',
-                         beta, out.data[:, m1:m2])
+                mmm(alpha, aa, 'N', buf2[:m2 - m1], 'C',
+                    beta, out.data[:, m1:m2])
             # out.data[:, m1:m2] = m12.data[:, :m2 - m1]
 
         if rrequest:
@@ -939,7 +989,7 @@ def fastmmm2(a, b, out):
                 m1 = min(row * m, M)
                 m2 = min(m1 + m, M)
                 if mym > 0 and m2 > m1:
-                    block = np.empty((mym, m2 - m1), out.dtype)
+                    block = xp.empty((mym, m2 - m1), out.dtype)
                     blocks.append((m1, m2, block))
                     requests.append(comm.receive(block, row, 12, False))
 
@@ -950,20 +1000,22 @@ def fastmmm2(a, b, out):
     return out
 
 
-def fastmmm2notsym(a, b, out):
-    if a.comm:
-        assert b.comm is a.comm
-        if a.comm.size > 1:
-            assert out.comm == a.comm
-            assert out.state == 'a sum is needed'
+def mmm_nc(a, b, out, alpha, beta, mmm):
+    """Symmetric parallel matrix-matrix multiplication.
 
+    :::
+
+                †
+        c <- αab  + βc
+    """
     comm = a.dist.comm
     M, N = a.shape
     m = (M + comm.size - 1) // comm.size
     mym = len(a.data)
+    xp = a.xp
 
-    buf1 = np.empty((m, N), dtype=a.dtype)
-    buf2 = np.empty((m, N), dtype=a.dtype)
+    buf1 = xp.empty((m, N), dtype=a.dtype)
+    buf2 = xp.empty((m, N), dtype=a.dtype)
     aa = a.data
     bb = b.data
 
@@ -984,7 +1036,7 @@ def fastmmm2notsym(a, b, out):
         m1 = min(((comm.rank - r) % comm.size) * m, M)
         m2 = min(m1 + m, M)
         # symmmmmmmmmmmmmmmmmmmmmmetricccccccccccccccc ??
-        blas.mmm(1.0, aa, 'N', bb[:m2 - m1], 'C', 1.0, out.data[:, m1:m2])
+        mmm(alpha, aa, 'N', bb[:m2 - m1], 'C', beta, out.data[:, m1:m2])
 
         if rrequest:
             comm.wait(rrequest)
