@@ -1,21 +1,21 @@
 from __future__ import annotations
 
+from functools import cached_property
 from math import pi
-from typing import Sequence
-
+from typing import Sequence, Literal
 import numpy as np
 
 import gpaw.fftw as fftw
 from gpaw.core.arrays import DistributedArrays
 from gpaw.core.atom_centered_functions import UGAtomCenteredFunctions
 from gpaw.core.domain import Domain
-from gpaw.gpu import as_xp
+from gpaw.gpu import as_np, cupy_is_fake
 from gpaw.grid_descriptor import GridDescriptor
 from gpaw.mpi import MPIComm, serial_comm
-from gpaw.new import cached_property, zips
+from gpaw.new import zips
 from gpaw.typing import (Array1D, Array2D, Array3D, Array4D, ArrayLike1D,
                          ArrayLike2D, Vector)
-from gpaw.new.c import add_to_density, symmetrize_ft
+from gpaw.new.c import add_to_density, add_to_density_gpu, symmetrize_ft
 from gpaw.fd_operators import Gradient
 
 
@@ -106,12 +106,13 @@ class UGDesc(Domain):
                       self.kpt_c[:, np.newaxis])
 
     def new(self,
+            *,
+            kpt=None,
+            dtype=None,
+            comm: MPIComm | Literal['inherit'] | None = 'inherit',
             size=None,
             pbc=None,
-            kpt=None,
-            comm='inherit',
-            decomp=None,
-            dtype=None) -> UGDesc:
+            decomp=None) -> UGDesc:
         """Create new uniform grid description."""
         if decomp is None and comm == 'inherit':
             if size is None and pbc is None:
@@ -141,6 +142,9 @@ class UGDesc(Domain):
         """
         return UGArray(self, dims, comm, xp=xp)
 
+    def from_data(self, data):
+        return UGArray(self, data.shape[:-3], data=data)
+
     def blocks(self, data: np.ndarray):
         """Yield views of blocks of data."""
         s0, s1, s2 = self.parsize_c
@@ -163,11 +167,13 @@ class UGDesc(Domain):
                                 functions,
                                 positions,
                                 *,
+                                qspiral_v=None,
                                 atomdist=None,
                                 integral=None,
                                 cut=False,
                                 xp=None):
         """Create UGAtomCenteredFunctions object."""
+        assert qspiral_v is None
         return UGAtomCenteredFunctions(functions,
                                        positions,
                                        self,
@@ -363,7 +369,7 @@ class UGArray(DistributedArrays[UGDesc]):
         grid = self.desc
         dx = (grid.cell_cv[c]**2).sum()**0.5 / grid.size_c[c]
         x = np.arange(grid.start_c[c], grid.end_c[c]) * dx
-        return x, as_xp(y, np)
+        return x, as_np(y)
 
     def scatter_from(self, data=None):
         """Scatter data from rank-0 to all ranks."""
@@ -402,7 +408,7 @@ class UGArray(DistributedArrays[UGDesc]):
 
         if broadcast or comm.rank == 0:
             grid = self.desc.new(comm=serial_comm)
-            out = grid.empty(self.dims, xp=self.xp)
+            out = grid.empty(self.dims, comm=self.comm, xp=self.xp)
 
         if comm.rank != 0:
             # There can be several sends before the corresponding receives
@@ -469,8 +475,8 @@ class UGArray(DistributedArrays[UGDesc]):
         norm_x = []
         arrays_xR = self._arrays()
         for a_R in arrays_xR:
-            norm_x.append(np.vdot(a_R, a_R).real * self.desc.dv)
-        result = np.array(norm_x).reshape(self.mydims)
+            norm_x.append(self.xp.vdot(a_R, a_R).real * self.desc.dv)
+        result = self.xp.array(norm_x).reshape(self.mydims)
         self.desc.comm.sum(result)
         return result
 
@@ -541,7 +547,7 @@ class UGArray(DistributedArrays[UGDesc]):
 
         if self.desc.comm.size > 1:
             input = self.gather()
-            if input:
+            if input is not None:
                 output = input.interpolate(plan1, plan2,
                                            out.desc.new(comm=None))
                 out.scatter_from(output.data)
@@ -636,7 +642,7 @@ class UGArray(DistributedArrays[UGDesc]):
 
         if self.desc.comm.size > 1:
             input = self.gather()
-            if input:
+            if input is not None:
                 output = input.fft_restrict(plan1, plan2,
                                             out.desc.new(comm=None))
                 out.scatter_from(output.data)
@@ -698,8 +704,15 @@ class UGArray(DistributedArrays[UGDesc]):
                    out: UGArray | None = None) -> None:
         """Add weighted absolute square of data to output array."""
         assert out is not None
-        for f, psit_R in zips(weights, self.data):
-            add_to_density(f, psit_R, out.data)
+
+        if self.xp is np:
+            for f, psit_R in zips(weights, self.data):
+                add_to_density(f, psit_R, out.data)
+        elif cupy_is_fake:
+            for f, psit_R in zips(weights, self.data):
+                add_to_density(f, psit_R._data, out.data._data)  # type: ignore
+        else:
+            add_to_density_gpu(self.xp.asarray(weights), self.data, out.data)
 
     def symmetrize(self, rotation_scc, translation_sc):
         """Make data symmetric."""
@@ -730,7 +743,7 @@ class UGArray(DistributedArrays[UGDesc]):
         """Insert random numbers between -0.5 and 0.5 into data."""
         if seed is None:
             seed = self.comm.rank + self.desc.comm.rank * self.comm.size
-        rng = np.random.default_rng(seed)
+        rng = self.xp.random.default_rng(seed)
         a = self.data.view(float)
         rng.random(a.shape, out=a)
         a -= 0.5
