@@ -43,7 +43,7 @@ class CompensationChargeExpansionCoefficients:
 
     def get_charge(self, Q_aL):
         local_charge = sqrt(4 * pi) * sum(Q_L[0] for Q_L in Q_aL.values())
-        return Q_aL.partition.comm.sum(local_charge)
+        return Q_aL.partition.comm.sum_scalar(local_charge)
 
 
 class NullBackgroundCharge:
@@ -142,9 +142,9 @@ class Density:
 
     def __str__(self):
         s = 'Densities:\n'
-        s += '  Coarse grid: {0}*{1}*{2} grid\n'.format(*self.gd.N_c)
-        s += '  Fine grid: {0}*{1}*{2} grid\n'.format(*self.finegd.N_c)
-        s += '  Total Charge: {0:.6f}'.format(self.charge)
+        s += '  Coarse grid: {}*{}*{} grid\n'.format(*self.gd.N_c)
+        s += '  Fine grid: {}*{}*{} grid\n'.format(*self.finegd.N_c)
+        s += f'  Total Charge: {self.charge:.6f}'
         if self.fixed:
             s += '\n  Fixed'
         return s
