@@ -93,10 +93,3 @@ import gpaw.dfpt.responsecalculator
 import gpaw.dfpt.phononperturbation
 import gpaw.dfpt.dynamicalmatrix
 import gpaw.dfpt.electronphononcoupling
-
-__all__ = []
-__all__.extend(phononcalculator.__all__)
-__all__.extend(responsecalculator.__all__)
-__all__.extend(phononperturbation.__all__)
-__all__.extend(dynamicalmatrix.__all__)
-__all__.extend(electronphononcoupling.__all__)
