@@ -25,12 +25,12 @@ else:
         import gpaw.gpu.cpupy as cupy
         import gpaw.gpu.cpupyx as cupyx
 
-__all__ = ['cupy', 'cupyx', 'as_xp', 'synchronize']
+__all__ = ['cupy', 'cupyx', 'as_xp', 'as_np', 'synchronize']
 
 
 def synchronize():
     if not cupy_is_fake:
-        cupy.cuda.runtime.deviceSynchronize()
+        cupy.cuda.get_current_stream().synchronize()
 
 
 def setup():
@@ -45,6 +45,19 @@ def setup():
         _gpaw.gpaw_gpu_init()
 
 
+def as_np(array: np.ndarray | cupy.ndarray) -> np.ndarray:
+    """Transfer array to CPU (if not already there).
+
+    Parameters
+    ==========
+    array:
+        Numpy or CuPy array.
+    """
+    if isinstance(array, np.ndarray):
+        return array
+    return cupy.asnumpy(array)
+
+
 def as_xp(array, xp):
     """Transfer array to CPU or GPU (if not already there).
 
@@ -65,6 +78,13 @@ def as_xp(array, xp):
     return array
 
 
+def einsum(subscripts, *operands, out):
+    if isinstance(out, np.ndarray):
+        np.einsum(subscripts, *operands, out=out)
+    else:
+        out[:] = cupy.einsum(subscripts, *operands)
+
+
 def cupy_eigh(a: cupy.ndarray, UPLO: str) -> tuple[cupy.ndarray, cupy.ndarray]:
     """Wrapper for ``eigh()``.
 
