@@ -139,7 +139,7 @@ def _non_local(calc: GPAWOld | ASECalculator,
 
     nocc = max(((kpt.f_n / kpt.weight) > ftol).sum()
                for kpt in wfs.kpt_u)
-    nocc = kd.comm.max(wfs.bd.comm.sum(int(nocc)))
+    nocc = kd.comm.max_scalar(wfs.bd.comm.sum_scalar(int(nocc)))
 
     coulomb = coulomb_interaction(omega, wfs.gd, kd)
     sym = Symmetry(kd)
@@ -231,8 +231,11 @@ def _calculate_eigenvalues(kpt1, kpts2, paw, kd, coulomb, sym, wfs, spos_ac):
         P_ni = proj1all[a]
         vv_n = np.einsum('ni, ij, nj -> n',
                          P_ni.conj(), VV_ii, P_ni).real
-        vc_n = np.einsum('ni, ij, nj -> n',
-                         P_ni.conj(), paw.VC_aii[a], P_ni).real
+        if paw.VC_aii[a] is not None:
+            vc_n = np.einsum('ni, ij, nj -> n',
+                             P_ni.conj(), paw.VC_aii[a], P_ni).real
+        else:
+            vc_n = 0.0
         E_n -= (2 * vv_n + vc_n)
 
     return E_n
