@@ -16,7 +16,7 @@ from gpaw.occupations import FixedOccupationNumbers, ParallelLayout
 def prepare_mom_calculation(calc,
                             atoms,
                             numbers,
-                            use_projections=False,
+                            use_projections=True,
                             update_numbers=True,
                             use_fixed_occupations=False,
                             width=0.0,
@@ -32,13 +32,12 @@ def prepare_mom_calculation(calc,
         Occupation numbers (in the range from 0 to 1). Used
         for the initialization of the MOM reference orbitals.
     use_projections: bool
-        If True, the occupied orbitals at iteration k are chosen
-        as the orbitals ``|psi^(k)_m>`` with the biggest weights
-        ``P_m`` evaluated as the projections onto the manifold of
-        reference orbitals ``|psi_n>``: ``P_m = (Sum_n(|O_nm|^2))^0.5
-        (O_nm = <psi_n|psi^(k)_m>)`` see
-        :doi:`10.1021/acs.jctc.7b00994`. If False (default),
-        the weights are evaluated as: ``P_m = max_n(|O_nm|)``
+        If True (default), the occupied orbitals at iteration k are
+        chosen as the orbitals ``|psi^(k)_m>`` with the biggest
+        weights ``P_m`` evaluated as the projections onto the manifold
+        of reference orbitals ``|psi_n>``: ``P_m = (Sum_n(|O_nm|^2))^0.5
+        (O_nm = <psi_n|psi^(k)_m>)`` see :doi:`10.1021/acs.jctc.7b00994`.
+        If False, the weights are evaluated as: ``P_m = max_n(|O_nm|)``,
         see :doi:`10.1021/acs.jctc.0c00488`.
     update_numbers: bool
         If True (default), 'numbers' gets updated with the calculated
@@ -137,7 +136,7 @@ class OccupationsMOM:
         if self.width == 0.0:
             s += 'off\n'
         else:
-            s += '{0:.4f} eV\n'.format(self.width * Ha)
+            s += f'{self.width * Ha:.4f} eV\n'
         return s
 
     def calculate(self,
@@ -201,9 +200,8 @@ class OccupationsMOM:
                     self.wf[kpt.s][f_n_unique] = kpt.psit_nG[occupied].copy()
                     # Atomic contributions times projector overlaps
                     self.p_an[kpt.s][f_n_unique] = \
-                        dict([(a, np.dot(self.wfs.setups[a].dO_ii,
-                                         P_ni[occupied].T))
-                              for a, P_ni in kpt.P_ani.items()])
+                        {a: np.dot(self.wfs.setups[a].dO_ii, P_ni[occupied].T)
+                         for a, P_ni in kpt.P_ani.items()}
 
         self.initialized = True
 
