@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import warnings
+from functools import cached_property
 from pathlib import Path
 from types import SimpleNamespace
 from typing import IO, Any, Union
@@ -11,8 +12,8 @@ from ase.units import Bohr, Ha
 from gpaw import __version__
 from gpaw.core import UGArray
 from gpaw.dos import DOSCalculator
-from gpaw.mpi import world, synchronize_atoms
-from gpaw.new import Timer, cached_property
+from gpaw.mpi import world, synchronize_atoms, broadcast as bcast
+from gpaw.new import Timer
 from gpaw.new.builder import builder as create_builder
 from gpaw.new.calculation import (DFTCalculation, DFTState,
                                   ReuseWaveFunctionsError, units)
@@ -150,23 +151,15 @@ class ASECalculator:
                         atoms.set_initial_magnetic_moments(magmom_a)
 
                 if changes & {'numbers', 'pbc'}:
-                    # Start from scratch:
-                    self.calculation = None
+                    self.calculation = None  # start from scratch
                 else:
-                    ibzwfs = self.calculation.state.ibzwfs
-                    kpt_parallel_only = (ibzwfs.band_comm.size == 1 and
-                                         ibzwfs.domain_comm.size == 1)
-                    if kpt_parallel_only:
-                        try:
-                            self.create_new_calculation_from_old(atoms)
-                        except ReuseWaveFunctionsError:
-                            self.calculation = None
-                        else:
-                            self.converge()
-                            changes = set()
+                    try:
+                        self.create_new_calculation_from_old(atoms)
+                    except ReuseWaveFunctionsError:
+                        self.calculation = None  # start from scratch
                     else:
-                        # Not implemented: just start from scratch
-                        self.calculation = None
+                        self.converge()
+                        changes = set()
 
         if self.calculation is None:
             self.create_new_calculation(atoms)
@@ -176,17 +169,16 @@ class ASECalculator:
             self.move_atoms(atoms)
             self.converge()
 
-        if prop not in self.calculation.results:
-            if prop == 'forces':
-                with self.timer('Forces'):
-                    self.calculation.forces()
-            elif prop == 'stress':
-                with self.timer('Stress'):
-                    self.calculation.stress()
-            elif prop == 'dipole':
-                self.calculation.dipole()
-            else:
-                raise KeyError('Unknown property:', prop)
+        if prop == 'forces':
+            with self.timer('Forces'):
+                self.calculation.forces()
+        elif prop == 'stress':
+            with self.timer('Stress'):
+                self.calculation.stress()
+        elif prop == 'dipole':
+            self.calculation.dipole()
+        elif prop not in self.calculation.results:
+            raise KeyError('Unknown property:', prop)
 
         return self.calculation.results[prop] * units[prop]
 
@@ -244,7 +236,7 @@ class ASECalculator:
         """Helper method for force-convergence criterium."""
         with self.timer('Forces'):
             self.calculation.forces(silent=True)
-        return self.calculation.results['forces']
+        return self.calculation.results['forces'].copy()
 
     def __del__(self):
         self.log('---')
@@ -277,6 +269,16 @@ class ASECalculator:
     def get_magnetic_moments(self, atoms: Atoms | None = None) -> Array1D:
         return self.calculate_property(atoms, 'magmoms')
 
+    def get_non_collinear_magnetic_moment(self,
+                                          atoms: Atoms | None = None
+                                          ) -> Array1D:
+        return self.calculate_property(atoms, 'non_collinear_magmom')
+
+    def get_non_collinear_magnetic_moments(self,
+                                           atoms: Atoms | None = None
+                                           ) -> Array2D:
+        return self.calculate_property(atoms, 'non_collinear_magmoms')
+
     def write(self, filename, mode=''):
         """Write calculator object to a file.
 
@@ -303,19 +305,41 @@ class ASECalculator:
         kwargs = {**dict(self.params.items()), **kwargs}
         return GPAW(**kwargs)
 
-    def get_pseudo_wave_function(self, band, kpt=0, spin=0,
-                                 periodic=False) -> Array3D:
+    def get_pseudo_wave_function(self, band, kpt=0, spin=None,
+                                 periodic=False,
+                                 broadcast=True) -> Array3D:
         state = self.calculation.state
-        wfs = state.ibzwfs.get_wfs(spin=spin, kpt=kpt, n1=band, n2=band + 1)
-        basis = getattr(self.calculation.scf_loop.hamiltonian, 'basis', None)
-        grid = state.density.nt_sR.desc
-        wfs = wfs.to_uniform_grid_wave_functions(grid, basis)
-        psit_R = wfs.psit_nX[0]
-        if not psit_R.desc.pbc.all():
-            psit_R = psit_R.to_pbc_grid()
-        if periodic:
-            psit_R.multiply_by_eikr(-psit_R.desc.kpt_c)
-        return psit_R.data * Bohr**-1.5
+        collinear = state.ibzwfs.collinear
+        if collinear:
+            if spin is None:
+                spin = 0
+        else:
+            assert spin is None
+        wfs = state.ibzwfs.get_wfs(spin=spin if collinear else 0,
+                                   kpt=kpt,
+                                   n1=band, n2=band + 1)
+        if wfs is not None:
+            basis = getattr(self.calculation.scf_loop.hamiltonian,
+                            'basis', None)
+            grid = state.density.nt_sR.desc.new(comm=None)
+            if collinear:
+                wfs = wfs.to_uniform_grid_wave_functions(grid, basis)
+                psit_R = wfs.psit_nX[0]
+            else:
+                psit_sG = wfs.psit_nX[0]
+                grid = grid.new(kpt=psit_sG.desc.kpt_c,
+                                dtype=psit_sG.desc.dtype)
+                psit_R = psit_sG.ifft(grid=grid)
+            if not psit_R.desc.pbc.all():
+                psit_R = psit_R.to_pbc_grid()
+            if periodic:
+                psit_R.multiply_by_eikr(-psit_R.desc.kpt_c)
+            array_R = psit_R.data * Bohr**-1.5
+        else:
+            array_R = None
+        if broadcast:
+            array_R = bcast(array_R, 0, self.calculation.comm)
+        return array_R
 
     def get_atoms(self):
         atoms = self.atoms.copy()
@@ -361,8 +385,8 @@ class ASECalculator:
         if isinstance(vHt_x, UGArray):
             return vHt_x.gather(broadcast=True).to_pbc_grid().data * Ha
 
-        return vHt_x.ifft(
-            grid=self.calculation.pot_calc.fine_grid).data * Ha
+        grid = self.calculation.pot_calc.fine_grid
+        return vHt_x.ifft(grid=grid).gather(broadcast=True).data * Ha
 
     def get_atomic_electrostatic_potentials(self):
         return self.calculation.electrostatic_potential().atomic_potentials()
@@ -498,6 +522,7 @@ class ASECalculator:
             dexc += xc.calculate_paw_correction(
                 setup,
                 np.array([pack(D_ii) for D_ii in D_sii.real]))
+        dexc = state.ibzwfs.domain_comm.sum_scalar(dexc)
         return (exct + dexc - state.potential.energies['xc']) * Ha
 
     def diagonalize_full_hamiltonian(self,
