@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import importlib
 import os
+from functools import cached_property
 from types import ModuleType, SimpleNamespace
 from typing import Any, Union
 
@@ -18,7 +19,7 @@ from gpaw.gpu.mpi import CuPyMPI
 from gpaw.mixer import MixerWrapper, get_mixer_from_keywords
 from gpaw.mpi import (MPIComm, Parallelization, serial_comm, synchronize_atoms,
                       world)
-from gpaw.new import cached_property, prod
+from gpaw.new import prod
 from gpaw.new.basis import create_basis
 from gpaw.new.brillouin import BZPoints, MonkhorstPackKPoints
 from gpaw.new.density import Density
@@ -29,7 +30,7 @@ from gpaw.new.smearing import OccupationNumberCalculator
 from gpaw.new.symmetry import create_symmetries_object
 from gpaw.new.xc import create_functional
 from gpaw.setup import Setups
-from gpaw.typing import Array2D, ArrayLike1D, ArrayLike2D
+from gpaw.typing import Array2D, ArrayLike1D, ArrayLike2D, DTypeLike
 from gpaw.utilities.gpts import get_number_of_grid_points
 from gpaw.xc import XC
 from gpaw.new.c import GPU_AWARE_MPI
@@ -51,6 +52,7 @@ def builder(atoms: Atoms,
 
     mode = params.mode.copy()
     name = mode.pop('name')
+    mode.pop('force_complex_dtype', False)
     assert name in {'pw', 'lcao', 'fd', 'tb', 'atom'}
     mod = importlib.import_module(f'gpaw.new.{name}.builder')
     name = name.title() if name == 'atom' else name.upper()
@@ -82,7 +84,8 @@ class DFTComponentsBuilder:
         self.spin_degeneracy = self.ncomponents % 2 + 1
 
         if isinstance(params.xc, (dict, str)):
-            self._xc = XC(params.xc, collinear=(self.ncomponents < 4))
+            self._xc = XC(params.xc, collinear=(self.ncomponents < 4),
+                          xp=self.xp)
         else:
             self._xc = params.xc
 
@@ -125,15 +128,14 @@ class DFTComponentsBuilder:
         if self.ncomponents == 4:
             self.nbands *= 2
 
-        self.dtype = params.dtype
-        if self.dtype is None:
-            if self.ibz.bz.gamma_only:
+        self.dtype: DTypeLike
+        if self.params.mode.get('force_complex_dtype', False):
+            self.dtype = complex
+        else:
+            if self.ibz.bz.gamma_only and self.ncomponents < 4:
                 self.dtype = float
             else:
                 self.dtype = complex
-        elif not self.ibz.bz.gamma_only and self.dtype != complex:
-            raise ValueError('Can not use dtype=float for non gamma-point '
-                             'calculation')
 
         self.grid, self.fine_grid = self.create_uniform_grids()
 
@@ -145,17 +147,21 @@ class DFTComponentsBuilder:
 
         self.interpolation_desc: Domain
         self.electrostatic_potential_desc: Domain
-        self.atomdist: AtomDistribution
 
     def __repr__(self):
         return f'{self.__class__.__name__}({self.atoms}, {self.params})'
 
+    @cached_property
+    def atomdist(self) -> AtomDistribution:
+        return AtomDistribution(
+            self.grid.ranks_from_fractional_positions(self.fracpos_ac),
+            self.grid.comm)
+
     def create_uniform_grids(self):
         raise NotImplementedError
 
     def create_xc_functional(self):
-        return create_functional(self._xc,
-                                 self.fine_grid)
+        return create_functional(self._xc, self.fine_grid, self.xp)
 
     def check_cell(self, cell):
         number_of_lattice_vectors = cell.rank
@@ -407,7 +413,7 @@ def calculate_number_of_bands(nbands: int | str | None,
         # Number of bound partial waves:
         nbandsmax = sum(setup.get_default_nbands()
                         for setup in setups)
-        N = int(np.ceil((1.2 * (nvalence + M) / 2))) + 4
+        N = int(np.ceil(1.2 * (nvalence + M) / 2)) + 4
         N = min(N, nbandsmax)
         if is_lcao and N > nao:
             N = nao
