@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from functools import cached_property
 from typing import Any, Union
 
 import numpy as np
@@ -9,9 +10,9 @@ from ase.units import Bohr, Ha
 from gpaw.core.atom_arrays import AtomDistribution
 from gpaw.densities import Densities
 from gpaw.electrostatic_potential import ElectrostaticPotential
-from gpaw.gpu import as_xp
+from gpaw.gpu import as_np
 from gpaw.mpi import broadcast_float, world
-from gpaw.new import cached_property, zips
+from gpaw.new import zips
 from gpaw.new.density import Density
 from gpaw.new.ibzwfs import IBZWaveFunctions, create_ibz_wave_functions
 from gpaw.new.input_parameters import InputParameters
@@ -40,6 +41,7 @@ units = {'energy': Ha,
          'dipole': Bohr,
          'magmom': 1.0,
          'magmoms': 1.0,
+         'non_collinear_magmom': 1.0,
          'non_collinear_magmoms': 1.0}
 
 
@@ -116,7 +118,8 @@ class DFTCalculation:
         scf_loop = builder.create_scf_loop()
 
         pot_calc = builder.create_potential_calculator()
-        potential, _ = pot_calc.calculate(density)
+        potential, _ = pot_calc.calculate(
+            density, kpt_band_comm=builder.communicators['D'])
         ibzwfs = builder.create_ibz_wave_functions(
             basis_set, potential, log=log)
         state = DFTState(ibzwfs, density, potential)
@@ -152,13 +155,12 @@ class DFTCalculation:
 
     def iconverge(self, convergence=None, maxiter=None, calculate_forces=None):
         self.state.ibzwfs.make_sure_wfs_are_read_from_gpw_file()
-        for ctx in self.scf_loop.iterate(self.state,
+        yield from self.scf_loop.iterate(self.state,
                                          self.pot_calc,
                                          convergence,
                                          maxiter,
                                          calculate_forces,
-                                         log=self.log):
-            yield ctx
+                                         log=self.log)
 
     def converge(self,
                  convergence=None,
@@ -194,6 +196,8 @@ class DFTCalculation:
         self.results['energy'] = total_extrapolated
 
     def dipole(self):
+        if 'dipole' in self.results:
+            return
         dipole_v = self.state.density.calculate_dipole_moment(self.fracpos_ac)
         x, y, z = dipole_v * Bohr
         self.log(f'dipole moment: [{x:.6f}, {y:.6f}, {z:.6f}]  # |e|*Ang\n')
@@ -204,6 +208,7 @@ class DFTCalculation:
         self.results['magmom'] = mm_v[2]
         self.results['magmoms'] = mm_av[:, 2].copy()
         self.results['non_collinear_magmoms'] = mm_av
+        self.results['non_collinear_magmom'] = mm_v
 
         if self.state.density.ncomponents > 1:
             x, y, z = mm_v
@@ -219,6 +224,19 @@ class DFTCalculation:
 
     def forces(self, silent=False):
         """Calculate atomic forces."""
+        if 'forces' not in self.results or silent:
+            self._calculate_forces()
+
+        if not silent:
+            self.log('\nforces: [  # eV/Ang')
+            F_av = self.results['forces'] * (Ha / Bohr)
+            for a, setup in enumerate(self.setups):
+                x, y, z = F_av[a]
+                c = ',' if a < len(F_av) - 1 else ']'
+                self.log(f'  [{x:9.3f}, {y:9.3f}, {z:9.3f}]{c}'
+                         f'  # {setup.symbol:2} {a}')
+
+    def _calculate_forces(self):
         xc = self.pot_calc.xc
         assert not hasattr(xc.xc, 'setup_force_corrections')
 
@@ -248,26 +266,18 @@ class DFTCalculation:
         for a, dF_v in Fvbar_av.items():
             F_av[a] += dF_v[:, 0]
 
-        F_av = as_xp(F_av, np)
+        F_av = as_np(F_av)
 
         domain_comm = ccc_aL.layout.atomdist.comm
         domain_comm.sum(F_av)
 
         F_av = self.state.ibzwfs.ibz.symmetries.symmetrize_forces(F_av)
-
-        if not silent:
-            self.log('\nforces: [  # eV/Ang')
-            s = Ha / Bohr
-            for a, setup in enumerate(self.setups):
-                x, y, z = F_av[a] * s
-                c = ',' if a < len(F_av) - 1 else ']'
-                self.log(f'  [{x:9.3f}, {y:9.3f}, {z:9.3f}]{c}'
-                         f'  # {setup.symbol:2} {a}')
-
         self.comm.broadcast(F_av, 0)
         self.results['forces'] = F_av
 
     def stress(self):
+        if 'stress' in self.results:
+            return
         stress_vv = self.pot_calc.stress(self.state)
         self.log('\nstress tensor: [  # eV/Ang^3')
         for (x, y, z), c in zips(stress_vv * (Ha / Bohr**3), ',,]'):
@@ -300,6 +310,10 @@ class DFTCalculation:
         if params.mode['name'] != 'pw':
             raise ReuseWaveFunctionsError
 
+        ibzwfs = self.state.ibzwfs
+        if ibzwfs.domain_comm.size != 1:
+            raise ReuseWaveFunctionsError
+
         if not self.state.density.nt_sR.desc.pbc_c.all():
             raise ReuseWaveFunctionsError
 
@@ -309,7 +323,7 @@ class DFTCalculation:
         builder = create_builder(atoms, params, self.comm)
 
         kpt_kc = builder.ibz.kpt_kc
-        old_kpt_kc = self.state.ibzwfs.ibz.kpt_kc
+        old_kpt_kc = ibzwfs.ibz.kpt_kc
         if len(kpt_kc) != len(old_kpt_kc):
             raise ReuseWaveFunctionsError
         if abs(kpt_kc - old_kpt_kc).max() > 1e-9:
@@ -334,7 +348,7 @@ class DFTCalculation:
         pot_calc = builder.create_potential_calculator()
         potential, _ = pot_calc.calculate(density)
 
-        old_ibzwfs = self.state.ibzwfs
+        old_ibzwfs = ibzwfs
 
         def create_wfs(spin, q, k, kpt_c, weight):
             wfs = old_ibzwfs.wfs_qs[q][spin]
