@@ -22,10 +22,18 @@ class LCAOEigensolver(Eigensolver):
                  matrix_calculator: HamiltonianMatrixCalculator):
         H_MM = matrix_calculator.calculate_matrix(wfs)
         eig_M = H_MM.eighg(wfs.L_MM, wfs.domain_comm)
-        N = min(len(eig_M), wfs.nbands)
+        C_Mn = H_MM  # rename (H_MM now contains the eigenvectors)
+        assert len(eig_M) >= wfs.nbands
+        N = wfs.nbands
         wfs._eig_n = np.empty(wfs.nbands)
-        wfs._eig_n[:N] = eig_M[:N]
-        wfs.C_nM.data[:N] = H_MM.data.T[:N]
+        wfs._eig_n[:] = eig_M[:N]
+        comm = C_Mn.dist.comm
+        if comm.size == 1:
+            wfs.C_nM.data[:] = C_Mn.data.T[:N]
+        else:
+            C_Mn = C_Mn.gather(broadcast=True)
+            n1, n2 = wfs.C_nM.dist.my_row_range()
+            wfs.C_nM.data[:] = C_Mn.data.T[n1:n2]
 
         # Make sure wfs.C_nM and (lazy) wfs.P_ani are in sync:
         wfs._P_ani = None
