@@ -27,6 +27,8 @@ from gpaw.spinorbit import soc as soc_terms
 from gpaw.typing import Array1D, Array2D, Array3D
 from gpaw.utilities import pack, pack2, unpack
 from gpaw.yml import indent
+from gpaw.mpi import MPIComm, serial_comm
+from gpaw.new.external_potential import ExternalPotential
 
 
 class PotentialCalculator:
@@ -36,10 +38,12 @@ class PotentialCalculator:
                  setups: list[Setup],
                  *,
                  fracpos_ac: Array2D,
+                 external_potential: ExternalPotential | None = None,
                  soc: bool = False):
         self.poisson_solver = poisson_solver
         self.xc = xc
         self.setups = setups
+        self.external_potential = external_potential or ExternalPotential()
         self.fracpos_ac = fracpos_ac
         self.soc = soc
 
@@ -67,6 +71,7 @@ class PotentialCalculator:
                   density,
                   ibzwfs=None,
                   vHt_x: DistributedArrays | None = None,
+                  kpt_band_comm: MPIComm | None = None
                   ) -> tuple[Potential, AtomArrays]:
         energies, vt_sR, dedtaut_sr, vHt_x = self.calculate_pseudo_potential(
             density, ibzwfs, vHt_x)
@@ -88,10 +93,22 @@ class PotentialCalculator:
 
         energies['kinetic'] = e_kinetic
 
+        if kpt_band_comm is None:
+            if ibzwfs is None:
+                kpt_band_comm = serial_comm
+            else:
+                kpt_band_comm = ibzwfs.kpt_band_comm
         Q_aL = self.calculate_charges(vHt_x)
         dH_asii, corrections = calculate_non_local_potential(
-            self.setups, density, self.xc, Q_aL, self.soc)
+            self.setups,
+            density,
+            self.xc,
+            self.external_potential,
+            Q_aL,
+            self.soc,
+            kpt_band_comm)
 
+        energies['spinorbit'] = 0
         for key, e in corrections.items():
             if 0:
                 print(f'{key:10} {energies[key]:15.9f} {e:15.9f}')
@@ -103,27 +120,38 @@ class PotentialCalculator:
 def calculate_non_local_potential(setups,
                                   density,
                                   xc,
+                                  ext_pot,
                                   Q_aL,
-                                  soc: bool) -> tuple[AtomArrays,
-                                                      dict[str, float]]:
+                                  soc: bool,
+                                  kpt_band_comm: MPIComm
+                                  ) -> tuple[AtomArrays,
+                                             dict[str, float]]:
     dtype = float if density.ncomponents < 4 else complex
     D_asii = density.D_asii.to_xp(np)
     dH_asii = D_asii.layout.new(dtype=dtype).empty(density.ncomponents)
     Q_aL = Q_aL.to_xp(np)
     energy_corrections: DefaultDict[str, float] = defaultdict(float)
+    rank = 0
     for a, D_sii in D_asii.items():
-        Q_L = Q_aL[a]
-        setup = setups[a]
-        dH_sii, corrections = calculate_non_local_potential1(
-            setup, xc, D_sii, Q_L, soc)
-        dH_asii[a][:] = dH_sii
-        for key, e in corrections.items():
-            energy_corrections[key] += e
+        if rank % kpt_band_comm.size == kpt_band_comm.rank:
+            Q_L = Q_aL[a]
+            setup = setups[a]
+            dH_sii, corrections = calculate_non_local_potential1(
+                setup, xc, ext_pot, D_sii, Q_L, soc)
+            dH_asii[a][:] = dH_sii
+            for key, e in corrections.items():
+                energy_corrections[key] += e
+        else:
+            dH_asii[a][:] = 0.0
+        rank += 1
+
+    kpt_band_comm.sum(dH_asii.data)
 
     # Sum over domain:
-    names = ['kinetic', 'coulomb', 'zero', 'xc', 'external']
+    names = ['kinetic', 'coulomb', 'zero', 'xc', 'external', 'spinorbit']
     energies = np.array([energy_corrections[name] for name in names])
     density.D_asii.layout.atomdist.comm.sum(energies)
+    kpt_band_comm.sum(energies)
 
     return (dH_asii.to_xp(density.D_asii.layout.xp),
             dict(zips(names, energies)))
@@ -131,6 +159,7 @@ def calculate_non_local_potential(setups,
 
 def calculate_non_local_potential1(setup: Setup,
                                    xc: Functional,
+                                   ext_pot,
                                    D_sii: Array3D,
                                    Q_L: Array1D,
                                    soc: bool) -> tuple[Array3D,
@@ -149,21 +178,30 @@ def calculate_non_local_potential1(setup: Setup,
     e_coulomb = setup.M + D_p @ (setup.M_p + setup.M_pp @ D_p)
 
     dH_sp = np.zeros_like(D_sp, dtype=float if ncomponents < 4 else complex)
+
+    e_soc = 0.
     if soc:
-        dH_sp[1:4] = pack2(soc_terms(setup, xc.xc, D_sp))
+        dHsoc_sii = soc_terms(setup, xc.xc, D_sp)
+        e_soc += (D_sii[1:4] * dHsoc_sii).sum().real
+        dH_sp[1:4] = pack2(dHsoc_sii)
+
     dH_sp[:ndensities] = dH_p
     e_xc = xc.calculate_paw_correction(setup, D_sp, dH_sp)
-    e_external = 0.0
-    if setup.hubbard_u is not None:
-        eU, dHU_sp = setup.hubbard_u.calculate(setup, D_sp)
-        e_xc += eU
-        dH_sp += dHU_sp
+
+    e_external = ext_pot.add_paw_correction(setup.Delta_pL[:, 0], dH_sp)
 
     dH_sii = unpack(dH_sp)
+
+    if setup.hubbard_u is not None:
+        eU, dHU_sii = setup.hubbard_u.calculate(setup, D_sii)
+        e_xc += eU
+        dH_sii += dHU_sii
+
     e_kinetic -= (D_sii * dH_sii).sum().real
 
     return dH_sii, {'kinetic': e_kinetic,
                     'coulomb': e_coulomb,
                     'zero': e_zero,
                     'xc': e_xc,
-                    'external': e_external}
+                    'external': e_external,
+                    'spinorbit': e_soc}
