@@ -277,9 +277,13 @@ class QSymmetryOp:
         return mypawcorr, Q_G
 
 
-def get_nmG(kpt1, kpt2, mypawcorr, n, qpd, I_G, pair_calc):
+def get_nmG(kpt1, kpt2, mypawcorr, n, qpd, I_G, pair_calc, timer=None):
+    if timer:
+        timer.start('utcc and pawcorr multiply')
     ut1cc_R = kpt1.ut_nR[n].conj()
     C1_aGi = mypawcorr.multiply(kpt1.P_ani, band=n)
+    if timer:
+        timer.stop('utcc and pawcorr multiply')
     n_mG = pair_calc.calculate_pair_density(
         ut1cc_R, C1_aGi, kpt2, qpd, I_G)
     return n_mG
@@ -376,6 +380,7 @@ def select_kpts(kpts, kd):
 
 class G0W0Calculator:
     def __init__(self, filename='gw', *,
+                 wd,
                  chi0calc,
                  wcalc,
                  kpts, bands, nbands=None,
@@ -384,6 +389,7 @@ class G0W0Calculator:
                  ecut_e,
                  frequencies=None,
                  exx_vxc_calculator,
+                 qcache,
                  ppa=False):
         """G0W0 calculator, initialized through G0W0 object.
 
@@ -427,18 +433,26 @@ class G0W0Calculator:
         self.wcalc = wcalc
         self.context = self.wcalc.context
         self.ppa = ppa
-        
-        # Note: self.chi0calc.wd should be our only representation
-        # of the frequencies.
+        self.qcache = qcache
+
+        # Note: self.wd should be our only representation of the frequencies.
         # We should therefore get rid of self.frequencies.
         # It is currently only used by the restart code,
         # so should be easy to remove after some further adaptation.
+        self.wd = wd
         self.frequencies = frequencies
 
         self.ecut_e = ecut_e / Ha
 
         self.context.print(gw_logo)
 
+        if self.chi0calc.gs.metallic:
+            self.context.print('WARNING: \n'
+                               'The current GW implementation cannot'
+                               ' handle intraband screening. \n'
+                               'This results in poor k-point'
+                               ' convergence for metals')
+
         self.fxc_modes = fxc_modes
 
         if self.fxc_modes[0] != 'GW':
@@ -455,20 +469,6 @@ class G0W0Calculator:
         self.filename = filename
         self.eta = eta / Ha
 
-        if self.context.comm.rank == 0:
-            # We pass a serial communicator because the parallel handling
-            # is somewhat wonky, we'd rather do that ourselves:
-            try:
-                self.qcache = FileCache(f'qcache_{self.filename}',
-                                        comm=mpi.SerialCommunicator())
-            except TypeError as err:
-                raise RuntimeError(
-                    'File cache requires ASE master '
-                    'from September 20 2022 or newer.  '
-                    'You may need to pull newest ASE.') from err
-
-            self.qcache.strip_empties()
-
         self.kpts = kpts
         self.bands = bands
 
@@ -496,7 +496,7 @@ class G0W0Calculator:
         if self.ppa:
             self.context.print('Using Godby-Needs plasmon-pole approximation:')
             self.context.print('  Fitting energy: i*E0, E0 = %.3f Hartee'
-                               % self.chi0calc.wd.omega_w[1].imag)
+                               % self.wd.omega_w[1].imag)
         else:
             self.context.print('Using full frequency integration')
 
@@ -506,13 +506,15 @@ class G0W0Calculator:
         if kpts is None:
             isl.append('All k-points in IBZ')
         else:
-            kptstxt = ', '.join(['{0:d}'.format(k) for k in self.kpts])
+            kptstxt = ', '.join([f'{k:d}' for k in self.kpts])
             isl.append(f'k-points (IBZ indices): [{kptstxt}]')
         isl.extend([f'Band range: ({b1:d}, {b2:d})',
                     '',
                     'Computational parameters:'])
         if len(self.ecut_e) == 1:
-            isl.append(f'Plane wave cut-off: {self.chi0calc.ecut * Ha:g} eV')
+            isl.append(
+                'Plane wave cut-off: '
+                f'{self.chi0calc.chi0_body_calc.ecut * Ha:g} eV')
         else:
             assert len(self.ecut_e) > 1
             isl.append('Extrapolating to infinite plane wave cut-off using '
@@ -682,7 +684,7 @@ class G0W0Calculator:
                         continue
 
                     nc_G = n_G.conj()
-                    
+
                     # ie: ecut index for extrapolation
                     # kpt1.s: spin index of *
                     # k: k-point index of *
@@ -727,15 +729,15 @@ class G0W0Calculator:
         self.context.print(self.wcalc.coulomb.description())
 
         chi0calc = self.chi0calc
-        self.context.print(self.chi0calc.wd)
+        self.context.print(self.wd)
 
         # Find maximum size of chi-0 matrices:
-        nGmax = max(count_reciprocal_vectors(chi0calc.ecut,
+        nGmax = max(count_reciprocal_vectors(chi0calc.chi0_body_calc.ecut,
                                              self.wcalc.gs.gd, q_c)
                     for q_c in self.wcalc.qd.ibzk_kc)
-        nw = len(self.chi0calc.wd)
+        nw = len(self.wd)
 
-        size = self.chi0calc.integrator.blockcomm.size
+        size = self.chi0calc.chi0_body_calc.integrator.blockcomm.size
 
         mynGmax = (nGmax + size - 1) // size
         mynw = (nw + size - 1) // size
@@ -782,17 +784,17 @@ class G0W0Calculator:
         # Reset calculation
         sigmashape = (len(self.ecut_e), *self.shape)
         sigmas = {fxc_mode: Sigma(iq, q_c, fxc_mode, sigmashape,
-                  **self.get_validation_inputs())
+                                  **self.get_validation_inputs())
                   for fxc_mode in self.fxc_modes}
 
         chi0 = chi0calc.create_chi0(q_c)
 
-        m1 = chi0calc.nocc1
+        m1 = chi0calc.gs.nocc1
         for ie, ecut in enumerate(self.ecut_e):
             self.context.timer.start('W')
 
             # First time calculation
-            if ecut == chi0calc.ecut:
+            if ecut == chi0.qpd.ecut:
                 # Nothing to cut away:
                 m2 = self.nbands
             else:
@@ -814,7 +816,7 @@ class G0W0Calculator:
                     self.wcalc.qd, iq, q_c)):
 
                 for (progress, kpt1, kpt2)\
-                    in self.pair_distribution.kpt_pairs_by_q(bzq_c, 0, m2):
+                        in self.pair_distribution.kpt_pairs_by_q(bzq_c, 0, m2):
                     pb.update((nQ + progress) / self.wcalc.qd.mynk)
 
                     k1 = self.wcalc.gs.kd.bz2ibz_k[kpt1.K]
@@ -857,11 +859,11 @@ class G0W0Calculator:
             Wdict[fxc_mode] = self.wcalc.get_HW_model(rchi0,
                                                       fxc_mode=fxc_mode)
             if (chi0calc.chi0_body_calc.pawcorr is not None and
-                rqpd.ecut < chi0.qpd.ecut):
+                    rqpd.ecut < chi0.qpd.ecut):
                 assert not self.ppa, """In previous master, PPA with ecut
                 extrapolation was not working. Now it would work, but
                 disabling it here still for sake of it is not tested."""
-                
+
                 pw_map = PWMapping(rqpd, chi0.qpd)
                 # This is extremely bad behaviour! G0W0Calculator
                 # should not change properties on the
@@ -900,17 +902,17 @@ class G0W0Calculator:
         for s in range(self.wcalc.gs.nspins):
             for i, ik in enumerate(self.kpts):
                 self.context.print(
-                    '\nk-point ' + '{0} ({1}): ({2:.3f}, {3:.3f}, '
-                    '{4:.3f})'.format(i, ik, *ibzk_kc[ik]) +
+                    '\nk-point ' + '{} ({}): ({:.3f}, {:.3f}, '
+                    '{:.3f})'.format(i, ik, *ibzk_kc[ik]) +
                     '                ' + self.fxc_modes[0])
-                self.context.print('band' + ''.join('{0:>8}'.format(name)
+                self.context.print('band' + ''.join(f'{name:>8}'
                                                     for name in names))
 
                 def actually_print_results(resultset):
                     for n in range(b2 - b1):
                         self.context.print(
-                            '{0:4}'.format(n + b1) +
-                            ''.join('{0:8.3f}'.format(
+                            f'{n + b1:4}' +
+                            ''.join('{:8.3f}'.format(
                                 resultset[name][s, i, n]) for name in names))
 
                 for fxc_mode in results:
@@ -1049,6 +1051,20 @@ class G0W0(G0W0Calculator):
             Cuts chi0 into as many blocks as possible to reduce memory
             requirements as much as possible.
         """
+        # We pass a serial communicator because the parallel handling
+        # is somewhat wonky, we'd rather do that ourselves:
+        try:
+            qcache = FileCache(f'qcache_{filename}',
+                               comm=mpi.SerialCommunicator())
+        except TypeError as err:
+            raise RuntimeError(
+                'File cache requires ASE master '
+                'from September 20 2022 or newer.  '
+                'You may need to pull newest ASE.') from err
+        if world.rank == 0:
+            qcache.strip_empties()
+        mode = 'a' if qcache.filecount() > 1 else 'w'
+
         frequencies = get_frequencies(frequencies, domega0, omega2)
 
         # (calc can not actually be a calculator at all.)
@@ -1090,7 +1106,7 @@ class G0W0(G0W0Calculator):
                           'timeordered': True}
 
         from gpaw.response.chi0 import new_frequency_descriptor
-        wcontext = context.with_txt(filename + '.w.txt')
+        wcontext = context.with_txt(filename + '.w.txt', mode=mode)
         wd = new_frequency_descriptor(gs, wcontext, nbands, frequencies)
 
         chi0calc = Chi0Calculator(
@@ -1101,7 +1117,7 @@ class G0W0(G0W0Calculator):
             context=wcontext,
             **parameters)
 
-        bands = choose_bands(bands, relbands, gs.nvalence, chi0calc.nocc2)
+        bands = choose_bands(bands, relbands, gs.nvalence, chi0calc.gs.nocc2)
 
         coulomb = CoulombKernel.from_gs(gs, truncation=truncation)
         # XXX eta needs to be converted to Hartree here,
@@ -1123,6 +1139,7 @@ class G0W0(G0W0Calculator):
             snapshotfile_prefix=filename)
 
         super().__init__(filename=filename,
+                         wd=wd,
                          chi0calc=chi0calc,
                          wcalc=wcalc,
                          ecut_e=ecut_e,
@@ -1133,6 +1150,7 @@ class G0W0(G0W0Calculator):
                          frequencies=frequencies,
                          kpts=kpts,
                          exx_vxc_calculator=exx_vxc_calculator,
+                         qcache=qcache,
                          ppa=ppa,
                          **kwargs)
 
@@ -1149,6 +1167,7 @@ class G0W0(G0W0Calculator):
 
 class EXXVXCCalculator:
     """EXX and Kohn-Sham XC contribution."""
+
     def __init__(self, gpwfile, snapshotfile_prefix):
         self._gpwfile = gpwfile
         self._snapshotfile_prefix = snapshotfile_prefix
