@@ -4,13 +4,13 @@ from abc import ABC, abstractmethod
 import numpy as np
 
 from gpaw.sphere.integrate import spherical_truncation_function_collection
-from gpaw.sphere.rshe import calculate_reduced_rshe
 
 from gpaw.response import timer
 from gpaw.response.kspair import KohnShamKPointPair
 from gpaw.response.pair import phase_shifted_fft_indices
 from gpaw.response.site_paw import calculate_site_matrix_element_correction
-from gpaw.response.localft import extract_micro_setup, calculate_LSDA_Wxc
+from gpaw.response.localft import calculate_LSDA_Wxc, add_LSDA_trans_fxc
+from gpaw.response.site_data import AtomicSiteData
 
 
 class MatrixElement(ABC):
@@ -99,6 +99,12 @@ class MatrixElementCalculator(ABC):
              = | dr ψ_nks^*(r) A ψ_n'k+qs'(r)
                /
         """
+        self._add_pseudo_contribution(*self.extract_pseudo_waves(kptpair),
+                                      matrix_element=matrix_element)
+
+    def extract_pseudo_waves(self, kptpair):
+        """Extract the pseudo wave functions for each k-point pair transition.
+        """
         ikpt1 = kptpair.ikpt1
         ikpt2 = kptpair.ikpt2
 
@@ -117,8 +123,7 @@ class MatrixElementCalculator(ABC):
         ut1_mytR = ut1_hR[ikpt1.h_myt]
         ut2_mytR = ut2_hR[ikpt2.h_myt]
 
-        self._add_pseudo_contribution(
-            k1_c, k2_c, ut1_mytR, ut2_mytR, matrix_element)
+        return k1_c, k2_c, ut1_mytR, ut2_mytR
 
     def add_paw_correction(self, kptpair, matrix_element):
         r"""Add the matrix element PAW correction to an output array.
@@ -161,11 +166,12 @@ class MatrixElementCalculator(ABC):
 
     @abstractmethod
     def _add_pseudo_contribution(self, k1_c, k2_c, ut1_mytR, ut2_mytR,
-                                 matrix_element):
+                                 matrix_element: MatrixElement):
         """Add pseudo contribution based on the pseudo waves in real space."""
 
     @abstractmethod
-    def _add_paw_correction(self, P1_amyti, P2_amyti, matrix_element):
+    def _add_paw_correction(self, P1_amyti, P2_amyti,
+                            matrix_element: MatrixElement):
         """Add paw correction based on the projector overlaps."""
 
     def get_periodic_pseudo_waves(self, K, ikpt):
@@ -179,124 +185,207 @@ class MatrixElementCalculator(ABC):
         return ut_hR
 
 
-class PairDensity(MatrixElement):
-
+class PlaneWaveMatrixElement(MatrixElement):
     def zeros(self):
         return self.qpd.zeros(self.tblocks.blocksize)
 
 
-class NewPairDensityCalculator(MatrixElementCalculator):
-    r"""Class for calculating pair densities
+class PlaneWaveMatrixElementCalculator(MatrixElementCalculator):
+    r"""Abstract base class for calculating plane-wave matrix elements.
 
-    n_kt(G+q) = n_nks,n'k+qs'(G+q) = <nks| e^-i(G+q)r |n'k+qs'>
+    Calculates the following plane-wave matrix element for a given local
+    functional of the electron (spin-)density f[n](r) = f(n(r)) and k-point
+    pair (k, k + q):
+
+    f_kt(G+q) = f_(nks,n'k+qs')(G+q) = <ψ_nks| e^-i(G+q)r f(r) |ψ_n'k+qs'>
 
                 /
-              = | dr e^-i(G+q)r ψ_nks^*(r) ψ_n'k+qs'(r)
+              = | dr e^-i(G+q)r ψ_nks^*(r) ψ_n'k+qs'(r) f(r)
                 /
-
-    for a single k-point pair (k, k + q) in the plane-wave mode.
-
-    As always, the calculation is split in a pseudo contribution and a PAW
-    correction, n_kt(G+q) = ñ_kt(G+q) + Δn_kt(G+q).
     """
 
-    def __init__(self, gs, context):
+    def __init__(self, gs, context,
+                 rshelmax: int = -1,
+                 rshewmin: float | None = None):
+        """Construct the PlaneWaveMatrixElementCalculator.
+
+        Parameters
+        ----------
+        rshelmax : int
+            The maximum index l (l < 6) to use in the expansion of f(r) into
+            real spherical harmonics for the PAW correction.
+        rshewmin : float or None
+            If None, the f(r) will be fully expanded up to the chosen lmax.
+            Given as a float (0 < rshewmin < 1), rshewmin indicates what
+            coefficients to use in the expansion. If any (l,m) coefficient
+            contributes with less than a fraction of rshewmin on average, it
+            will not be included.
+        """
         super().__init__(gs, context)
 
-        # Save PAW correction for all calls with same q_c
-        self._pawcorr = None
+        # Expand local functional in real spherical harmonics around each atom
+        rshe_a = []
+        for a, micro_setup in enumerate(self.gs.micro_setups):
+            rshe, info_string = micro_setup.expand_function(
+                self.add_f, lmax=rshelmax, wmin=rshewmin)
+            self.print_rshe_info(a, info_string)
+            rshe_a.append(rshe)
+        self.rshe_a = rshe_a
+
+        # PAW correction tensor for a given q_c
         self._currentq_c = None
+        self._F_aGii = None
+
+    @abstractmethod
+    def add_f(gd, n_sx, f_x):
+        """Add the local functional f(n(r)) to the f_x output array."""
+
+    def print_rshe_info(self, a, info_string):
+        """Print information about the functional expansion at atom a."""
+        info_string = f'RSHE of atom {a}:\n' + info_string
+        self.context.print(info_string.replace('\n', '\n    ') + '\n')
 
     def initialize_paw_corrections(self, qpd):
         """Initialize the PAW corrections ahead of the actual calculation."""
         self.get_paw_corrections(qpd)
 
     def get_paw_corrections(self, qpd):
-        """Get PAW corrections correcsponding to a specific q-vector."""
-        if self._pawcorr is None \
-           or not np.allclose(qpd.q_c - self._currentq_c, 0.):
+        """Get PAW corrections corresponding to a specific q-vector."""
+        if self._currentq_c is None \
+           or not np.allclose(qpd.q_c, self._currentq_c):
             with self.context.timer('Initialize PAW corrections'):
-                self._pawcorr = self.gs.pair_density_paw_corrections(qpd)
+                self._F_aGii = self.gs.matrix_element_paw_corrections(
+                    qpd, self.rshe_a)
                 self._currentq_c = qpd.q_c
-
-        return self._pawcorr
+        return self._F_aGii
 
     @staticmethod
     def create_matrix_element(tblocks, qpd):
-        return PairDensity(tblocks, qpd)
+        return PlaneWaveMatrixElement(tblocks, qpd)
 
-    @timer('Calculate the pseudo pair density')
+    @timer('Calculate pseudo matrix element')
     def _add_pseudo_contribution(self, k1_c, k2_c, ut1_mytR, ut2_mytR,
-                                 pair_density):
-        r"""Add the pseudo pair density to an output array.
+                                 matrix_element: PlaneWaveMatrixElement):
+        r"""Add the pseudo matrix element to the output array.
 
-        The pseudo pair density is first evaluated on the coarse real-space
-        grid and then FFT'ed to reciprocal space,
+        The pseudo matrix element is evaluated on the coarse real-space grid
+        and FFT'ed to reciprocal space,
 
-                    /               ˷          ˷
-        ñ_kt(G+q) = | dr e^-i(G+q)r ψ_nks^*(r) ψ_n'k+qs'(r)
+        ˷           /               ˷          ˷
+        f_kt(G+q) = | dr e^-i(G+q)r ψ_nks^*(r) ψ_n'k+qs'(r) f(r)
                     /V0
                                  ˷          ˷
-                  = FFT_G[e^-iqr ψ_nks^*(r) ψ_n'k+qs'(r)]
+                  = FFT_G[e^-iqr ψ_nks^*(r) ψ_n'k+qs'(r) f(r)]
 
-        where the Kohn-Sham orbitals are normalized to the unit cell.
+        where the Kohn-Sham orbitals are normalized to the unit cell and the
+        functional f[n](r+R)=f(r) is lattice periodic.
         """
-        qpd = pair_density.qpd
-        n_mytG = pair_density.local_array_view
+        qpd = matrix_element.qpd
+        # G: reciprocal space
+        f_mytG = matrix_element.local_array_view
+        # R: real space
+        ft_mytR = self._evaluate_pseudo_matrix_element(ut1_mytR, ut2_mytR)
 
-        # Calculate the pseudo pair density in real space, up to a phase of
-        # e^(-i[k+q-k']r).
-        # This phase does not necessarily vanish, since k2_c only is required
-        # to equal k1_c + qpd.q_c modulo a reciprocal lattice vector.
-        nt_mytR = ut1_mytR.conj() * ut2_mytR
-
-        # Get the FFT indices corresponding to the Fourier transform
-        #                       ˷          ˷
+        # Get the FFT indices corresponding to the pair density Fourier
+        # transform             ˷          ˷
         # FFT_G[e^(-i[k+q-k']r) u_nks^*(r) u_n'k's'(r)]
+        # This includes a (k,k')-dependent phase, since k2_c only is required
+        # to equal k1_c + qpd.q_c modulo a reciprocal lattice vector.
         Q_G = phase_shifted_fft_indices(k1_c, k2_c, qpd)
 
-        # Add the desired plane-wave components of the FFT'ed pseudo pair
-        # density to the output array
-        for n_G, n_R in zip(n_mytG, nt_mytR):
-            n_G[:] += qpd.fft(n_R, 0, Q_G) * qpd.gd.dv
+        # Add the desired plane-wave components of the FFT'ed pseudo matrix
+        # element to the output array
+        for f_G, ft_R in zip(f_mytG, ft_mytR):
+            f_G[:] += qpd.fft(ft_R, 0, Q_G) * self.gs.gd.dv
 
-    @timer('Calculate the pair density PAW corrections')
-    def _add_paw_correction(self, P1_amyti, P2_amyti, pair_density):
-        r"""Add the pair-density PAW correction to the output array.
+    @timer('Evaluate pseudo matrix element')
+    def _evaluate_pseudo_matrix_element(self, ut1_mytR, ut2_mytR):
+        """Evaluate the pseudo matrix element in real-space."""
+        # Evaluate the pseudo pair density      ˷          ˷
+        nt_mytR = ut1_mytR.conj() * ut2_mytR  # u_nks^*(r) u_n'k's'(r)
+
+        # Evaluate the local functional f(n(r)) on the coarse real-space grid
+        # NB: Here we assume that f(r) is sufficiently smooth to be represented
+        # on a regular grid (unlike the wave functions).
+        n_sR, gd = self.gs.get_all_electron_density(gridrefinement=1)
+        f_R = gd.zeros()
+        self.add_f(gd, n_sR, f_R)
+
+        return nt_mytR * f_R[np.newaxis]
+
+    @timer('Calculate the matrix-element PAW corrections')
+    def _add_paw_correction(self, P1_amyti, P2_amyti,
+                            matrix_element: PlaneWaveMatrixElement):
+        r"""Add the matrix-element PAW correction to the output array.
 
         The correction is calculated from
                      __  __
                      \   \   ˷     ˷     ˷    ˷
-        Δn_kt(G+q) = /   /  <ψ_nks|p_ai><p_ai'|ψ_n'k+qs'> Q_aii'(G+q)
+        Δf_kt(G+q) = /   /  <ψ_nks|p_ai><p_ai'|ψ_n'k+qs'> F_aii'(G+q)
                      ‾‾  ‾‾
                      a   i,i'
 
-        where the pair-density PAW correction tensor is given by:
+        where the matrix-element PAW correction tensor is given by:
 
                       /
-        Q_aii'(G+q) = | dr e^-i(G+q)r [φ_ai^*(r-R_a) φ_ai'(r-R_a)
+        F_aii'(G+q) = | dr e^-i(G+q)r [φ_ai^*(r-R_a) φ_ai'(r-R_a)
                       /                  ˷             ˷
-                                       - φ_ai^*(r-R_a) φ_ai'(r-R_a)]
+                                       - φ_ai^*(r-R_a) φ_ai'(r-R_a)] f[n](r)
         """
-        n_mytG = pair_density.local_array_view
-        Q_aGii = self.get_paw_corrections(pair_density.qpd).Q_aGii
-        for a, Q_Gii in enumerate(Q_aGii):
+        f_mytG = matrix_element.local_array_view
+        F_aGii = self.get_paw_corrections(matrix_element.qpd)
+        for a, F_Gii in enumerate(F_aGii):
             # Make outer product of the projector overlaps
             P1ccP2_mytii = P1_amyti[a].conj()[..., np.newaxis] \
                 * P2_amyti[a][:, np.newaxis]
             # Sum over partial wave indices and add correction to the output
-            n_mytG[:] += np.einsum('tij, Gij -> tG', P1ccP2_mytii, Q_Gii)
+            f_mytG[:] += np.einsum('tij, Gij -> tG', P1ccP2_mytii, F_Gii)
+
+
+class NewPairDensityCalculator(PlaneWaveMatrixElementCalculator):
+    r"""Class for calculating pair densities
+
+    n_kt(G+q) = n_(nks,n'k+qs')(G+q) = <ψ_nks| e^-i(G+q)r |ψ_n'k+qs'>
+    """
+
+    def __init__(self, gs, context):
+        super().__init__(gs, context,
+                         # Expanding f(r) = 1 in real spherical harmonics only
+                         # involves l = 0
+                         rshelmax=0)
+
+    def add_f(self, gd, n_sx, f_x):
+        f_x[:] += 1.
+
+    def print_rshe_info(self, *args):
+        # The expansion in spherical harmonics is trivial (l = 0), so there is
+        # no need to print anything
+        pass
+
+
+class TransversePairPotentialCalculator(PlaneWaveMatrixElementCalculator):
+    r"""Calculator for the transverse magnetic pair potential.
+
+    The transverse magnetic pair potential is a plane-wave matrix element
+    where the local functional is the transverse LDA kernel:
+
+    W^⟂_kt(G+q) = W^⟂_(nks,n'k+qs')(G+q)
+
+                = <ψ_nks| e^-i(G+q)r f_LDA^-+(r) |ψ_n'k+qs'>
+    """
+
+    def add_f(self, gd, n_sx, f_x):
+        return add_LSDA_trans_fxc(gd, n_sx, f_x, fxc='ALDA')
 
 
 class SiteMatrixElement(MatrixElement):
-    def __init__(self, tblocks, qpd, atomic_site_data):
-        self.nsites = atomic_site_data.nsites
-        self.npartitions = atomic_site_data.npartitions
+    def __init__(self, tblocks, qpd, sites):
+        self.sites = sites
         super().__init__(tblocks, qpd)
 
     def zeros(self):
         return np.zeros(
-            (self.tblocks.blocksize, self.nsites, self.npartitions),
+            (self.tblocks.blocksize, len(self.sites), self.sites.npartitions),
             dtype=complex)
 
 
@@ -318,7 +407,7 @@ class SiteMatrixElementCalculator(MatrixElementCalculator):
     For details, see [publication in preparation].
     """
 
-    def __init__(self, gs, context, atomic_site_data,
+    def __init__(self, gs, context, sites,
                  rshelmax: int = -1,
                  rshewmin: float | None = None):
         """Construct the SiteMatrixElementCalculator.
@@ -329,25 +418,38 @@ class SiteMatrixElementCalculator(MatrixElementCalculator):
             The maximum index l (l < 6) to use in the expansion of f(r) into
             real spherical harmonics for the PAW correction.
         rshewmin : float or None
-            If None, the PAW correction will be fully expanded up to the chosen
-            lmax. Given as a float (0 < rshewmin < 1), rshewmin indicates what
+            If None, the f(r) will be fully expanded up to the chosen lmax.
+            Given as a float (0 < rshewmin < 1), rshewmin indicates what
             coefficients to use in the expansion. If any (l,m) coefficient
             contributes with less than a fraction of rshewmin on average, it
             will not be included.
         """
         super().__init__(gs, context)
-        self.atomic_site_data = atomic_site_data
+        self.sites = sites
+        self.site_data = AtomicSiteData(self.gs, sites)
 
-        self.rshelmax = rshelmax
-        self.rshewmin = rshewmin
+        # Expand local functional in real spherical harmonics around each site
+        rshe_a = []
+        for a, micro_setup in enumerate(self.site_data.micro_setup_a):
+            rshe, info_string = micro_setup.expand_function(
+                self.add_f, lmax=rshelmax, wmin=rshewmin)
+            self.print_rshe_info(a, info_string)
+            rshe_a.append(rshe)
+        self.rshe_a = rshe_a
 
         # PAW correction tensor
         self._F_apii = None
 
     @abstractmethod
-    def add_f(gd, n_sx, f_x):
+    def add_f(self, gd, n_sx, f_x):
         """Add the local functional f(n(r)) to the f_x output array."""
 
+    def print_rshe_info(self, a, info_string):
+        """Print information about the expansion at site a."""
+        A = self.sites.A_a[a]  # Atomic index of site a
+        info_string = f'RSHE of site {a} (atom {A}):\n' + info_string
+        self.context.print(info_string.replace('\n', '\n    ') + '\n')
+
     def get_paw_correction_tensor(self):
         if self._F_apii is None:
             self._F_apii = self.calculate_paw_correction_tensor()
@@ -356,39 +458,22 @@ class SiteMatrixElementCalculator(MatrixElementCalculator):
     def calculate_paw_correction_tensor(self):
         """Calculate the site matrix element correction tensor F_ii'^ap."""
         F_apii = []
-        adata = self.atomic_site_data
-        for a, (A, rc_p, lambd_p) in enumerate(zip(
-                adata.A_a, adata.rc_ap, adata.lambd_ap)):
-            # Expand local function in real spherical harmonics
-            micro_setup = extract_micro_setup(self.gs, A)
-            rshe, info_string = self.perform_rshe(micro_setup)
-            self.print_rshe_info(a, A, info_string)
-
+        for rshe, A, rc_p, lambd_p in zip(
+                self.rshe_a, self.sites.A_a,
+                self.sites.rc_ap, self.site_data.lambd_ap):
             # Calculate the PAW correction
-            pawdata = self.gs.pawdatasets[A]
+            pawdata = self.gs.pawdatasets.by_atom[A]
             F_apii.append(calculate_site_matrix_element_correction(
-                pawdata, rshe, rc_p, adata.drcut, lambd_p))
+                pawdata, rshe, rc_p, self.site_data.drcut, lambd_p))
 
         return F_apii
 
-    def perform_rshe(self, micro_setup):
-        """Expand the functional f(n(r)) into real spherical harmonics."""
-        f_ng = micro_setup.evaluate_function(self.add_f)
-        return calculate_reduced_rshe(
-            micro_setup.rgd, f_ng, micro_setup.Y_nL,
-            self.rshelmax, self.rshewmin)
-
-    def print_rshe_info(self, a, A, info_string):
-        """Print information about the expansion at site a."""
-        info_string = f'RSHE of site {a} (atom {A}):\n' + info_string
-        self.context.print(info_string.replace('\n', '\n    ') + '\n')
-
     def create_matrix_element(self, tblocks, qpd):
-        return SiteMatrixElement(tblocks, qpd, self.atomic_site_data)
+        return SiteMatrixElement(tblocks, qpd, self.sites)
 
     @timer('Calculate pseudo site matrix element')
     def _add_pseudo_contribution(self, k1_c, k2_c, ut1_mytR, ut2_mytR,
-                                 site_matrix_element):
+                                 matrix_element: SiteMatrixElement):
         """Add the pseudo site matrix element to the output array.
 
         The pseudo matrix element is evaluated on the coarse real-space grid
@@ -416,25 +501,26 @@ class SiteMatrixElementCalculator(MatrixElementCalculator):
 
         # Set up spherical truncation function collection on the coarse
         # real-space grid with the KPointDescriptor of the q-point.
-        adata = self.atomic_site_data
         stfc = spherical_truncation_function_collection(
-            self.gs.gd, adata.spos_ac,
-            adata.rc_ap, adata.drcut, adata.lambd_ap,
-            kd=site_matrix_element.qpd.kd, dtype=complex)
+            self.gs.gd, self.site_data.spos_ac,
+            self.sites.rc_ap, self.site_data.drcut, self.site_data.lambd_ap,
+            kd=matrix_element.qpd.kd, dtype=complex)
 
         # Integrate Θ(r∊Ω_ap) f(r) ñ_kt(r)
         ntlocal = nt_mytR.shape[0]
-        ft_amytp = {a: np.empty((ntlocal, adata.npartitions), dtype=complex)
-                    for a in range(adata.nsites)}
+        ft_amytp = {a: np.empty((ntlocal, self.sites.npartitions),
+                                dtype=complex)
+                    for a in range(len(self.sites))}
         stfc.integrate(nt_mytR * f_R[np.newaxis], ft_amytp, q=0)
 
         # Add integral to output array
-        f_mytap = site_matrix_element.array
-        for a in range(adata.nsites):
+        f_mytap = matrix_element.array
+        for a in range(len(self.sites)):
             f_mytap[:, a] += ft_amytp[a]
 
     @timer('Calculate site matrix element PAW correction')
-    def _add_paw_correction(self, P1_Amyti, P2_Amyti, site_matrix_element):
+    def _add_paw_correction(self, P1_Amyti, P2_Amyti,
+                            matrix_element: SiteMatrixElement):
         r"""Add the site matrix element PAW correction to the output array.
 
         For every site a, we only need a PAW correction for that site itself,
@@ -446,10 +532,10 @@ class SiteMatrixElementCalculator(MatrixElementCalculator):
 
         where F_apii' is the site matrix element correction tensor.
         """
-        f_mytap = site_matrix_element.array
+        f_mytap = matrix_element.array
         F_apii = self.get_paw_correction_tensor()
         for a, (A, F_pii) in enumerate(zip(
-                self.atomic_site_data.A_a, F_apii)):
+                self.sites.A_a, F_apii)):
             # Make outer product of the projector overlaps
             P1ccP2_mytii = P1_Amyti[A].conj()[..., np.newaxis] \
                 * P2_Amyti[A][:, np.newaxis]
@@ -465,8 +551,8 @@ class SitePairDensityCalculator(SiteMatrixElementCalculator):
     n^ap_(nks,n'k+qs') = <ψ_nks|Θ(r∊Ω_ap)|ψ_n'k+qs'>
     """
 
-    def __init__(self, gs, context, atomic_site_data):
-        super().__init__(gs, context, atomic_site_data,
+    def __init__(self, gs, context, sites):
+        super().__init__(gs, context, sites,
                          # Expanding f(r) = 1 in real spherical harmonics only
                          # involves l = 0
                          rshelmax=0)
@@ -480,14 +566,13 @@ class SitePairDensityCalculator(SiteMatrixElementCalculator):
         pass
 
 
-class SitePairSpinSplittingCalculator(SiteMatrixElementCalculator):
-    """Class for calculating site pair spin splittings.
+class SiteZeemanPairEnergyCalculator(SiteMatrixElementCalculator):
+    """Class for calculating site Zeeman pair energies.
 
-    The site pair spin splitting corresponds to a site matrix element with
-    f(r) = - 2 W_xc^z(r):
+    The site Zeeman pair energy is defined as the site matrix element with
+    f(r) = - W_xc^z(r):
 
-    Δ^(xc,ap)_(nks,n'k+qs') = - 2 <ψ_nks|Θ(r∊Ω_ap)W_xc^z(r)|ψ_n'k+qs'>
+    E^(Z,ap)_(nks,n'k+qs') = - <ψ_nks|Θ(r∊Ω_ap)W_xc^z(r)|ψ_n'k+qs'>
     """
-
     def add_f(self, gd, n_sx, f_x):
-        f_x[:] += - 2. * calculate_LSDA_Wxc(gd, n_sx)
+        f_x[:] += - calculate_LSDA_Wxc(gd, n_sx)
