@@ -1,10 +1,7 @@
-import numbers
-
 import numpy as np
 
 from gpaw.response import ResponseGroundStateAdapter, ResponseContext, timer
 from gpaw.response.pw_parallelization import block_partition
-from gpaw.response.symmetry import KPointFinder
 from gpaw.utilities.blas import mmm
 
 
@@ -85,12 +82,8 @@ class KPointPairFactory:
                                                       nblocks)
         self.nblocks = nblocks
 
-        self.kptfinder = KPointFinder(self.gs.kd.bzk_kc)
         self.context.print('Number of blocks:', nblocks)
 
-    def find_kpoint(self, k_c):
-        return self.kptfinder.find(k_c)
-
     def distribute_k_points_and_bands(self, band1, band2, kpts=None):
         """Distribute spins, k-points and bands.
 
@@ -134,7 +127,7 @@ class KPointPairFactory:
         return PairDistribution(self, mysKn1n2)
 
     @timer('Get a k-point')
-    def get_k_point(self, s, k_c, n1, n2, block=False):
+    def get_k_point(self, s, K, n1, n2, block=False):
         """Return wave functions for a specific k-point and spin.
 
         s: int
@@ -150,13 +143,6 @@ class KPointPairFactory:
         gs = self.gs
         kd = gs.kd
 
-        # Parse kpoint: is k_c an index or a vector
-        if not isinstance(k_c, numbers.Integral):
-            K = self.kptfinder.find(k_c)
-        else:
-            # Fall back to index
-            K = k_c
-
         if block:
             nblocks = self.blockcomm.size
             rank = self.blockcomm.rank
@@ -199,22 +185,19 @@ class KPointPairFactory:
                       ut_nR, eps_n, f_n, P_ani, k_c)
 
     @timer('Get kpoint pair')
-    def get_kpoint_pair(self, qpd, s, Kork_c, n1, n2, m1, m2, block=False):
+    def get_kpoint_pair(self, qpd, s, K, n1, n2, m1, m2, block=False):
         assert m1 <= m2
         assert n1 <= n2
 
-        if isinstance(Kork_c, int):
-            # If k_c is an integer then it refers to
-            # the index of the kpoint in the BZ
-            k_c = self.gs.kd.bzk_kc[Kork_c]
-        else:
-            k_c = Kork_c
+        kptfinder = self.gs.kpoints.kptfinder
+
+        k_c = self.gs.kd.bzk_kc[K]
+        K1 = kptfinder.find(k_c)
+        K2 = kptfinder.find(k_c + qpd.q_c)
 
-        q_c = qpd.q_c
         with self.context.timer('get k-points'):
-            kpt1 = self.get_k_point(s, k_c, n1, n2)
-            # K2 = wfs.kd.find_k_plus_q(q_c, [kpt1.K])[0]
-            kpt2 = self.get_k_point(s, k_c + q_c, m1, m2, block=block)
+            kpt1 = self.get_k_point(s, K1, n1, n2)
+            kpt2 = self.get_k_point(s, K2, m1, m2, block=block)
 
         with self.context.timer('fft indices'):
             Q_G = phase_shifted_fft_indices(kpt1.k_c, kpt2.k_c, qpd)
@@ -351,7 +334,7 @@ class ActualPairDensityCalculator:
         k_v = 2 * np.pi * np.dot(kpt1.k_c, np.linalg.inv(gd.cell_cv).T)
 
         ut_vR = self.ut_sKnvR[kpt1.s][kpt1.K][n - kpt1.n1]
-        atomdata_a = self.gs.pawdatasets
+        atomdata_a = self.gs.pawdatasets.by_atom
         C_avi = [np.dot(atomdata.nabla_iiv.T, P_ni[n - kpt1.na])
                  for atomdata, P_ni in zip(atomdata_a, kpt1.P_ani)]
 
@@ -413,7 +396,7 @@ class ActualPairDensityCalculator:
         # Load kpoints
         gd = self.gs.gd
         k_v = 2 * np.pi * np.dot(kpt.k_c, np.linalg.inv(gd.cell_cv).T)
-        atomdata_a = self.gs.pawdatasets
+        atomdata_a = self.gs.pawdatasets.by_atom
 
         # Break bands into degenerate chunks
         degchunks_cn = []  # indexing c as chunk number
@@ -428,7 +411,7 @@ class ActualPairDensityCalculator:
                     raise RuntimeError(
                         'You are cutting over a degenerate band '
                         'using block parallelization.')
-                degchunks_cn.append((inds_n))
+                degchunks_cn.append(inds_n)
 
         # Calculate matrix elements by diagonalizing each block
         for ind_n in degchunks_cn:
@@ -447,8 +430,7 @@ class ActualPairDensityCalculator:
             for n in range(deg):
                 ut_vR = ut_nvR[n]
                 C_avi = [np.dot(atomdata.nabla_iiv.T, P_ni[ind_n[n] - na])
-                         for atomdata, P_ni in zip(atomdata_a,
-                                                   kpt.P_ani)]
+                         for atomdata, P_ni in zip(atomdata_a, kpt.P_ani)]
 
                 nabla0_nv = -self.gs.gd.integrate(ut_vR, ut_nR).T
                 nt_n = self.gs.gd.integrate(ut_nR[n], ut_nR)
