@@ -67,7 +67,7 @@ def nablarlYL(L, R):
 
 
 g = [1.0]
-for l in range(9):
+for l in range(11):
     g.append(g[-1] * (l + 0.5))
 
 
@@ -148,7 +148,7 @@ def print_YL_table_code():
     print('YL = [')
     print('    # s, l=0:')
     print(f'    [({(4 * pi)**-0.5}, (0, 0, 0))],')
-    for l in range(1, 8):
+    for l in range(1, 9):
         s = 'spdfghijk'[l]
         print(f'    # {s}, l={l}:')
         for m in range(-l, l + 1):
@@ -465,4 +465,147 @@ YL = [
     [(0.7071627325245963, (7, 0, 0)),
      (-14.850417383016522, (5, 2, 0)),
      (24.75069563836087, (3, 4, 0)),
-     (-4.950139127672174, (1, 6, 0))]]
+     (-4.950139127672174, (1, 6, 0))],
+    # k, l=8:
+    [(-5.831413281398639, (1, 7, 0)),
+     (40.81989296979047, (3, 5, 0)),
+     (-40.81989296979047, (5, 3, 0)),
+     (5.831413281398639, (7, 1, 0))],
+    [(-2.9157066406993195, (0, 7, 1)),
+     (61.22983945468571, (2, 5, 1)),
+     (-102.04973242447618, (4, 3, 1)),
+     (20.409946484895237, (6, 1, 1))],
+    [(7.452658724833596, (3, 5, 0)),
+     (-3.1939965963572554, (1, 7, 0)),
+     (44.715952349001576, (1, 5, 2)),
+     (7.452658724833596, (5, 3, 0)),
+     (-149.05317449667191, (3, 3, 2)),
+     (-3.1939965963572554, (7, 1, 0)),
+     (44.715952349001576, (5, 1, 2))],
+    [(31.04919559888297, (2, 5, 1)),
+     (-3.449910622098108, (0, 7, 1)),
+     (13.799642488392433, (0, 5, 3)),
+     (17.24955311049054, (4, 3, 1)),
+     (-137.99642488392433, (2, 3, 3)),
+     (-17.24955311049054, (6, 1, 1)),
+     (68.99821244196217, (4, 1, 3))],
+    [(-1.9136660990373229, (3, 5, 0)),
+     (-1.9136660990373229, (1, 7, 0)),
+     (45.927986376895745, (1, 5, 2)),
+     (-76.54664396149292, (1, 3, 4)),
+     (1.9136660990373229, (7, 1, 0)),
+     (1.9136660990373229, (5, 3, 0)),
+     (-45.927986376895745, (5, 1, 2)),
+     (76.54664396149292, (3, 1, 4))],
+    [(18.528992329433162, (4, 3, 1)),
+     (3.705798465886632, (2, 5, 1)),
+     (-49.41064621182176, (2, 3, 3)),
+     (-3.705798465886632, (0, 7, 1)),
+     (24.70532310591088, (0, 5, 3)),
+     (-19.764258484728707, (0, 3, 5)),
+     (11.117395397659896, (6, 1, 1)),
+     (-74.11596931773265, (4, 1, 3)),
+     (59.29277545418611, (2, 1, 5))],
+    [(-0.912304516869819, (7, 1, 0)),
+     (-2.7369135506094566, (5, 3, 0)),
+     (27.36913550609457, (5, 1, 2)),
+     (-2.7369135506094566, (3, 5, 0)),
+     (54.73827101218914, (3, 3, 2)),
+     (-72.98436134958551, (3, 1, 4)),
+     (-0.912304516869819, (1, 7, 0)),
+     (27.36913550609457, (1, 5, 2)),
+     (-72.98436134958551, (1, 3, 4)),
+     (29.193744539834206, (1, 1, 6))],
+    [(-3.8164436064572986, (6, 1, 1)),
+     (-11.449330819371895, (4, 3, 1)),
+     (30.53154885165839, (4, 1, 3)),
+     (-11.449330819371895, (2, 5, 1)),
+     (61.06309770331678, (2, 3, 3)),
+     (-36.63785862199006, (2, 1, 5)),
+     (-3.8164436064572986, (0, 7, 1)),
+     (30.53154885165839, (0, 5, 3)),
+     (-36.63785862199006, (0, 3, 5)),
+     (6.978639737521917, (0, 1, 7))],
+    [(0.31803696720477487, (8, 0, 0)),
+     (1.2721478688190995, (6, 2, 0)),
+     (-10.177182950552796, (6, 0, 2)),
+     (1.9082218032286493, (4, 4, 0)),
+     (-30.53154885165839, (4, 2, 2)),
+     (30.53154885165839, (4, 0, 4)),
+     (1.2721478688190995, (2, 6, 0)),
+     (-30.53154885165839, (2, 4, 2)),
+     (61.06309770331678, (2, 2, 4)),
+     (-16.283492720884475, (2, 0, 6)),
+     (0.31803696720477487, (0, 8, 0)),
+     (-10.177182950552796, (0, 6, 2)),
+     (30.53154885165839, (0, 4, 4)),
+     (-16.283492720884475, (0, 2, 6)),
+     (1.1631066229203195, (0, 0, 8))],
+    [(-3.8164436064572986, (7, 0, 1)),
+     (-11.449330819371895, (5, 2, 1)),
+     (30.53154885165839, (5, 0, 3)),
+     (-11.449330819371895, (3, 4, 1)),
+     (61.06309770331678, (3, 2, 3)),
+     (-36.63785862199006, (3, 0, 5)),
+     (-3.8164436064572986, (1, 6, 1)),
+     (30.53154885165839, (1, 4, 3)),
+     (-36.63785862199006, (1, 2, 5)),
+     (6.978639737521917, (1, 0, 7))],
+    [(0.912304516869819, (2, 6, 0)),
+     (-13.684567753047284, (2, 4, 2)),
+     (0.4561522584349095, (0, 8, 0)),
+     (-13.684567753047284, (0, 6, 2)),
+     (36.492180674792756, (0, 4, 4)),
+     (-14.596872269917103, (0, 2, 6)),
+     (-0.4561522584349095, (8, 0, 0)),
+     (-0.912304516869819, (6, 2, 0)),
+     (13.684567753047284, (6, 0, 2)),
+     (13.684567753047284, (4, 2, 2)),
+     (-36.492180674792756, (4, 0, 4)),
+     (14.596872269917103, (2, 0, 6))],
+    [(-3.705798465886632, (5, 2, 1)),
+     (-18.528992329433162, (3, 4, 1)),
+     (49.41064621182176, (3, 2, 3)),
+     (-11.117395397659896, (1, 6, 1)),
+     (74.11596931773265, (1, 4, 3)),
+     (-59.29277545418611, (1, 2, 5)),
+     (3.705798465886632, (7, 0, 1)),
+     (-24.70532310591088, (5, 0, 3)),
+     (19.764258484728707, (3, 0, 5))],
+    [(-4.784165247593307, (4, 4, 0)),
+     (-1.9136660990373229, (2, 6, 0)),
+     (57.40998297111968, (2, 4, 2)),
+     (0.4784165247593307, (0, 8, 0)),
+     (-11.481996594223936, (0, 6, 2)),
+     (19.13666099037323, (0, 4, 4)),
+     (-1.9136660990373229, (6, 2, 0)),
+     (57.40998297111968, (4, 2, 2)),
+     (-114.81996594223936, (2, 2, 4)),
+     (0.4784165247593307, (8, 0, 0)),
+     (-11.481996594223936, (6, 0, 2)),
+     (19.13666099037323, (4, 0, 4))],
+    [(17.24955311049054, (3, 4, 1)),
+     (-17.24955311049054, (1, 6, 1)),
+     (68.99821244196217, (1, 4, 3)),
+     (31.04919559888297, (5, 2, 1)),
+     (-137.99642488392433, (3, 2, 3)),
+     (-3.449910622098108, (7, 0, 1)),
+     (13.799642488392433, (5, 0, 3))],
+    [(-7.452658724833596, (2, 6, 0)),
+     (0.5323327660595426, (0, 8, 0)),
+     (-7.452658724833596, (0, 6, 2)),
+     (111.78988087250394, (2, 4, 2)),
+     (7.452658724833596, (6, 2, 0)),
+     (-111.78988087250394, (4, 2, 2)),
+     (-0.5323327660595426, (8, 0, 0)),
+     (7.452658724833596, (6, 0, 2))],
+    [(-20.409946484895237, (1, 6, 1)),
+     (102.04973242447618, (3, 4, 1)),
+     (-61.22983945468571, (5, 2, 1)),
+     (2.9157066406993195, (7, 0, 1))],
+    [(0.7289266601748299, (0, 8, 0)),
+     (-20.409946484895237, (2, 6, 0)),
+     (51.02486621223809, (4, 4, 0)),
+     (-20.409946484895237, (6, 2, 0)),
+     (0.7289266601748299, (8, 0, 0))],
+]
