@@ -20,8 +20,8 @@ for name in molecule_names + atom_names:
                       occupations=FermiDirac(0.0, fixmagmom=True),
                       txt=name + '.txt')
     if name in ['Na2', 'NaCl', 'NO', 'ClO', 'Cl', 'Si']:
-        atoms.calc.set(eigensolver='dav',
-                       mixer=Mixer(0.05, 2))
+        atoms.calc = atoms.calc.new(eigensolver='dav',
+                                    mixer=Mixer(0.05, 2))
     atoms.get_forces()
     c.write(atoms, id=id, name=name, relaxed=False)
     if len(atoms) > 1:
