@@ -28,7 +28,7 @@ for selection in [[0, 1, 2], [3, 4, 5]]:
          for i in range(3)])
 
     dimer.calc = EIQMMM(selection,
-                        GPAW(txt=name + '.txt', h=0.16),
+                        GPAW(mode='fd', txt=name + '.txt', h=0.16),
                         TIP4P(),
                         interaction,
                         vacuum=4,
@@ -40,7 +40,7 @@ for selection in [[0, 1, 2], [3, 4, 5]]:
     monomer = dimer[selection]
     monomer.center(vacuum=4)
     # Grrr.  PreconLBFGS breaks the symmetry!  Some one should fix that.
-    monomer.calc = GPAW(txt=name + 'M.txt', h=0.16, symmetry='off')
+    monomer.calc = GPAW(mode='fd', txt=name + 'M.txt', h=0.16, symmetry='off')
     opt = PreconLBFGS(monomer, precon=Exp(A=3), trajectory=name + 'M.traj')
     opt.run(0.02)
     e0 = monomer.get_potential_energy()
