@@ -27,10 +27,10 @@ for molecule in ['Adenine-thymine_complex_stack']:
     s2 = ss.find_connected(-1)
     assert len(ss) == len(s1) + len(s2)
 
-    c = GPAW(xc='PBE', h=h, nbands=-6,
-             occupations=FermiDirac(width=0.1), txt=None)
-    cdf = GPAW(xc='vdW-DF', h=h, nbands=-6, occupations=FermiDirac(width=0.1),
-               txt=None)
+    calc_params = dict(mode='fd', h=h, nbands=-6,
+                       occupations=FermiDirac(width=0.1), txt=None)
+    c = GPAW(**calc_params, xc='PBE')
+    cdf = GPAW(**calc_params, xc='vdW-DF')
 
     for s in [s1, s2, ss]:
         s.calc = c
