@@ -5,9 +5,8 @@ from gpaw import GPAW
 from gpaw.bfield import BField
 
 
-@pytest.mark.later
 @pytest.mark.serial
-def test_b_field():
+def test_b_field(gpaw_new):
     """Hydrogen atom in a magnetic field."""
     L = 2.0
     atom = Atoms('H', magmoms=[1], cell=[L, L, L], pbc=True)
@@ -28,8 +27,12 @@ def test_b_field():
     assert b2 - b1 == pytest.approx(B, abs=1e-6)
 
     # Non-collinear:
+    params = ({'magmoms': [(0.5, 0.5, 0)]}
+              if gpaw_new else
+              {'experimental': {'magmoms': [(0.5, 0.5, 0)]}})
     atom.calc = GPAW(mode='pw',
-                     experimental={'magmoms': [(0.5, 0.5, 0)]},
+                     symmetry='off',
+                     **params,
                      external=BField([B, 0, 0]))
     E3 = atom.get_potential_energy()
     a3, b3 = atom.calc.get_eigenvalues()
@@ -37,5 +40,10 @@ def test_b_field():
     assert E3 - E1 == pytest.approx(-B, abs=2e-5)
     assert a3 - a1 == pytest.approx(-B, abs=3e-5)
 
-    totmom_v, magmom_av = atom.calc.density.estimate_magnetic_moments()
+    if gpaw_new:
+        totmom_v, magmom_av = (
+            atom.calc.calculation.state.density.calculate_magnetic_moments())
+    else:
+        totmom_v, magmom_av = atom.calc.density.estimate_magnetic_moments()
     assert totmom_v == pytest.approx([1, 0, 0], abs=1e-5)
+    assert magmom_av[0] == pytest.approx([0.176, 0, 0], abs=1e-3)
