@@ -6,7 +6,6 @@ from gpaw.fdtd.polarizable_material import (PermittivityPlus,
                                             PolarizableMaterial,
                                             PolarizableSphere)
 from gpaw.mpi import world
-from gpaw.test import equal
 
 
 @pytest.mark.later
@@ -48,10 +47,9 @@ def test_fdtd_ed_wrapper(in_tmp_dir):
                         eigensolver='cg',
                         nbands=-1,
                         convergence={'energy': energy_eps},
-                        experimental={'niter_fixdensity': 2},
                         symmetry={'point_group': False})
-    equal(qsfdtd.energy, -0.631881,
-          energy_eps * qsfdtd.gs_calc.get_number_of_electrons())
+    assert qsfdtd.energy == pytest.approx(
+        -0.631881, abs=energy_eps * qsfdtd.gs_calc.get_number_of_electrons())
     qsfdtd.time_propagation('gs.gpw', kick_strength=[0.000, 0.000, 0.001],
                             time_step=10, iterations=5,
                             dipole_moment_file='dm.dat', restart_file='td.gpw')
@@ -63,7 +61,7 @@ def test_fdtd_ed_wrapper(in_tmp_dir):
     ref_qm_dipole_moment = [1.78620337e-11, -1.57782578e-11, 5.21368300e-01]
 
     tol = 1e-4
-    equal(qsfdtd.td_calc.hamiltonian.poisson.get_classical_dipole_moment(),
-          ref_cl_dipole_moment, tol)
-    equal(qsfdtd.td_calc.hamiltonian.poisson.get_quantum_dipole_moment(),
-          ref_qm_dipole_moment, tol)
+    cl_dm = qsfdtd.td_calc.hamiltonian.poisson.get_classical_dipole_moment()
+    qm_dm = qsfdtd.td_calc.hamiltonian.poisson.get_quantum_dipole_moment()
+    assert cl_dm == pytest.approx(ref_cl_dipole_moment, abs=tol)
+    assert qm_dm == pytest.approx(ref_qm_dipole_moment, abs=tol)
