@@ -1,6 +1,6 @@
 from ase import Atoms
 from gpaw import GPAW
-from gpaw.test import equal
+import pytest
 
 
 def test_generic_IP_oxygen():
@@ -21,8 +21,8 @@ def test_generic_IP_oxygen():
     assert abs(e1 - e0 - 13.989) < 0.04
 
     energy_tolerance = 0.004
-    equal(e0, -1.88477, energy_tolerance)
-    equal(e1, 12.11080, energy_tolerance)
+    assert e0 == pytest.approx(-1.88477, abs=energy_tolerance)
+    assert e1 == pytest.approx(12.11080, abs=energy_tolerance)
 
     # The first ionization energy for LDA oxygen is from this paper:
     # In-Ho Lee, Richard M. Martin, Phys. Rev. B 56 7197 (1997)
