@@ -7,12 +7,17 @@ from ase.optimize import BFGS
 
 from gpaw import GPAW
 from gpaw.mpi import world
-from gpaw.test import equal
+
+
+def timer(func, *args, **kwargs):
+    t0 = time()
+    ret = func(*args, **kwargs)
+    return ret, time() - t0
 
 
 @pytest.mark.later
-def test_generic_relax(in_tmp_dir):
-    a = 4.0    # Size of unit cell (Angstrom)
+def test_generic_relax(in_tmp_dir, needs_ase_master):
+    a = 4.0  # Size of unit cell (Angstrom)
     c = a / 2
     d = 0.74  # Experimental bond length
     molecule = Atoms('H2',
@@ -34,11 +39,6 @@ def test_generic_relax(in_tmp_dir):
     calc.write('H2f.gpw')
     calc.write('H2fa.gpw', mode='all')
 
-    def timer(func, *args, **kwargs):
-        t0 = time()
-        ret = func(*args, **kwargs)
-        return ret, time() - t0
-
     molecule = GPAW('H2.gpw', txt=None).get_atoms()
     f1, t1 = timer(molecule.get_forces)
     molecule = GPAW('H2a.gpw', txt=None).get_atoms()
@@ -104,6 +104,6 @@ def test_generic_relax(in_tmp_dir):
     assert abs(f - f0).max() < 5e-6  # 5 digits in txt file
 
     energy_tolerance = 0.002
-    equal(e1, -6.287873, energy_tolerance)
-    equal(e2, -6.290744, energy_tolerance)
-    equal(e2q, -6.290744, energy_tolerance)
+    assert e1 == pytest.approx(-6.287873, abs=energy_tolerance)
+    assert e2 == pytest.approx(-6.290744, abs=energy_tolerance)
+    assert e2q == pytest.approx(-6.290744, abs=energy_tolerance)
