@@ -14,21 +14,16 @@ def calc():
               basis='sz(dzp)',
               xc='GLLBSC',
               kpts={'size': (2, 2, 2), 'gamma': True},
+              convergence={'maximum iterations': 1},
               txt='si.txt') as calc:
         yield calc
 
 
-@pytest.mark.skip_for_new_gpaw
+@pytest.mark.later
 @pytest.mark.gllb
 @pytest.mark.libxc
 def test_lcao_gllb_si(in_tmp_dir, calc):
     si = bulk('Si', 'diamond', a=5.421)
-
-    def stopcalc():
-        calc.scf.converged = True
-
-    calc.attach(stopcalc, 1)
-
     si.calc = calc
     si.get_potential_energy()
 
