@@ -15,9 +15,11 @@ from numpy import array
 from ase import Atoms
 from gpaw import GPAW
 from gpaw.atom.basis import BasisMaker
+import pytest
 
 
-def test_lcao_largecellforce():
+@pytest.mark.later
+def test_lcao_largecellforce(gpaw_new):
     hbasis = BasisMaker('H').generate(1, 0, energysplit=1.8, tailnorm=0.03**.5)
     basis = {'H': hbasis}
 
@@ -40,7 +42,11 @@ def test_lcao_largecellforce():
     # Check that rightmost domain is in fact outside range of basis functions
     from gpaw.mpi import rank, size
     if rank == 0 and size > 1:
-        assert len(calc.wfs.basis_functions.atom_indices) < len(system)
+        if gpaw_new:
+            basis = calc.calculation.scf_loop.hamiltonian.basis
+        else:
+            basis = calc.wfs.basis_functions
+        assert len(basis.atom_indices) < len(system)
 
     fd = 0
 
