@@ -22,12 +22,8 @@ def test_lcao_lcao_elpa_kpts():
                                   band=2 if world.size > 4 else 1,
                                   kpt=2 if world.size > 2 else 1,
                                   elpasolver=elpasolver),
+                    convergence={'maximum iterations': 2},
                     txt='-')
-
-        def stopcalc():
-            calc.scf.converged = True
-
-        calc.attach(stopcalc, 2)
         atoms.calc = calc
         E = atoms.get_potential_energy()
         energies.append(E)
