@@ -11,7 +11,8 @@ def test_digonalize():
     atoms.cell = [3, 4, 5]
     atoms.center()
 
-    atoms.calc = GPAW(occupations=FermiDirac(width=0.1),
+    atoms.calc = GPAW(mode='fd',
+                      occupations=FermiDirac(width=0.1),
                       nbands=5)
     atoms.get_potential_energy()
 
