@@ -1,4 +1,3 @@
-import os
 import subprocess
 
 import pytest
@@ -11,10 +10,10 @@ from gpaw.utilities.ps2ae import PS2AE
 
 
 @pytest.mark.serial
-def test_bader(gpw_files, in_tmp_dir):
+def test_bader(gpw_files, in_tmp_dir, gpaw_new):
     """Test bader analysis on interpolated density."""
     calc = GPAW(gpw_files['c2h4_pw_nosym'])
-    if os.environ.get('GPAW_NEW'):
+    if gpaw_new:
         nt_sR = calc.calculation.densities().pseudo_densities()
         ne = nt_sR.integrate().sum()
         density = nt_sR.data.sum(0)
