@@ -2,13 +2,13 @@ import pytest
 
 
 @pytest.mark.response
-def test_two_phi_plw_integrals():
+def test_pair_density_paw_correction():
     import numpy as np
     from gpaw.lfc import LocalizedFunctionsCollection as LFC
     from gpaw.grid_descriptor import GridDescriptor
     from gpaw.atom.radialgd import EquidistantRadialGridDescriptor
     from gpaw.spline import Spline
-    from gpaw.response.paw import two_phi_planewave_integrals, Setuplet
+    from gpaw.response.paw import calculate_pair_density_correction, Setuplet
     # Initialize s, p, d (9 in total) wave and put them on grid
     rc = 2.0
     a = 2.5 * rc
@@ -52,10 +52,7 @@ def test_two_phi_plw_integrals():
     g = [np.exp(-(r / rc * b)**2) * r**l for l in range(lmax + 1)]
     l_j = range(lmax + 1)
     rcut_j = [rc] * (lmax + 1)
-    d1 = two_phi_planewave_integrals(k_G, pawdata=Setuplet(rgd=rgd, phi_jg=g,
-                                     phit_jg=np.zeros_like(g), l_j=l_j,
-                                     rcut_j=rcut_j))
-
-    d1 = d1.reshape(nkpt, m, m)
+    d1 = calculate_pair_density_correction(k_G, pawdata=Setuplet(
+        rgd=rgd, phi_jg=g, phit_jg=np.zeros_like(g), l_j=l_j, rcut_j=rcut_j))
 
     assert d0 == pytest.approx(d1, abs=1e-8)
