@@ -14,7 +14,7 @@ from gpaw.response.susceptibility import (ChiFactory, spectral_decomposition,
 from gpaw.response.fxc_kernels import AdiabaticFXCCalculator
 from gpaw.response.dyson import HXCScaling
 from gpaw.response.pair_functions import read_susceptibility_array
-from gpaw.test.conftest import response_band_cutoff
+from gpaw.test.gpwfile import response_band_cutoff
 
 
 @pytest.mark.kspair
