@@ -2,9 +2,8 @@ import pytest
 import numpy as np
 from ase import Atoms
 
-from gpaw import GPAW, FermiDirac
+from gpaw import GPAW, PW, FermiDirac, Mixer
 from gpaw.utilities import compiled_with_sl
-from gpaw import PW
 from gpaw.response.df import DielectricFunction
 from gpaw.mpi import world
 
@@ -12,6 +11,7 @@ from gpaw.mpi import world
 # should be equal, are.
 
 
+@pytest.mark.response
 @pytest.mark.slow
 def test_response_graphene(in_tmp_dir):
     a = 2.5
@@ -25,11 +25,14 @@ def test_response_graphene(in_tmp_dir):
                      (0.0, 0.0, c * 2.0)])
     GR.set_pbc((True, True, True))
     atoms = GR
+    # These are not physically-motivated kpoint grid sizes.
+    # They are the (nearly) the minimum number we need to test
+    # the symmetry off-on and gamma off-on difference.
     GSsettings = [
-        {'symmetry': 'off', 'kpts': {'density': 2.5, 'gamma': False}},
-        {'symmetry': {}, 'kpts': {'density': 2.5, 'gamma': False}},
-        {'symmetry': 'off', 'kpts': {'density': 2.5, 'gamma': True}},
-        {'symmetry': {}, 'kpts': {'density': 2.5, 'gamma': True}}]
+        {'symmetry': 'off', 'kpts': {'size': [3, 2, 1], 'gamma': False}},
+        {'symmetry': {}, 'kpts': {'size': [3, 2, 1], 'gamma': False}},
+        {'symmetry': 'off', 'kpts': {'size': [3, 2, 1], 'gamma': True}},
+        {'symmetry': {}, 'kpts': {'size': [3, 2, 1], 'gamma': True}}]
 
     DFsettings = [{'disable_point_group': True,
                    'disable_time_reversal': True},
@@ -46,9 +49,10 @@ def test_response_graphene(in_tmp_dir):
                            'nblocks': 2})
 
     for GSkwargs in GSsettings:
-        calc = GPAW(h=0.18,
-                    mode=PW(600),
+        calc = GPAW(mode=PW(200),
                     occupations=FermiDirac(0.2),
+                    mixer=Mixer(0.4),
+                    convergence={'eigenstates': 1e-4, 'density': 1e-3},
                     **GSkwargs)
 
         atoms.calc = calc
@@ -58,9 +62,11 @@ def test_response_graphene(in_tmp_dir):
         dfs = []
         for kwargs in DFsettings:
             DF = DielectricFunction(calc='gr.gpw',
-                                    domega0=0.2,
+                                    frequencies={'type': 'nonlinear',
+                                                 'domega0': 0.2},
                                     eta=0.2,
-                                    ecut=40.0,
+                                    ecut=15.0,
+                                    rate=0.001,
                                     **kwargs)
             df1, df2 = DF.get_dielectric_function()
             if world.rank == 0:
