@@ -1,10 +1,13 @@
 import pytest
 import numpy as np
 from gpaw.response.g0w0 import G0W0
+from gpaw.mpi import world
 
 
 @pytest.mark.response
-def test_ppa(in_tmp_dir, gpw_files, scalapack, needs_ase_master):
+def test_ppa(in_tmp_dir, gpw_files, scalapack, needs_ase_master, gpaw_new):
+    if gpaw_new and world.size > 1:
+        pytest.skip('Hybrids not working in parallel with GPAW_NEW=1')
     ref_result = np.asarray([[[11.30094393, 21.62842077],
                               [5.33751513, 16.06905725],
                               [8.75269938, 22.46579489]]])
