@@ -3,7 +3,7 @@
 import pytest
 from ase.build import bulk
 
-from gpaw import GPAW, PW, FermiDirac
+from gpaw import GPAW
 from gpaw.mpi import world
 from gpaw.response.g0w0 import G0W0
 
@@ -17,22 +17,12 @@ def generate_si_systems():
     return [si1, si2]
 
 
-def run(atoms, symm, nblocks):
-    atoms.calc = GPAW(mode=PW(250),
-                      eigensolver='rmm-diis',
-                      occupations=FermiDirac(0.01),
-                      symmetry=symm,
-                      kpts={'size': (2, 2, 2), 'gamma': True},
-                      convergence={'density': 1e-7},
-                      parallel={'domain': 1},
-                      txt='si.txt')
-    e = atoms.get_potential_energy()
-    scalapack = atoms.calc.wfs.bd.comm.size
-    atoms.calc.diagonalize_full_hamiltonian(nbands=8, scalapack=scalapack)
-    atoms.calc.write('si.gpw', mode='all')
-
+def run(gpw_filename, nblocks):
     # This tests checks the actual numerical accuracy which is asserted below
-    gw = G0W0('si.gpw', 'gw_None',
+    calc = GPAW(gpw_filename)
+    e = calc.get_potential_energy()
+
+    gw = G0W0(gpw_filename, 'gw_None',
               nbands=8, integrate_gamma=0,
               kpts=[(0, 0, 0), (0.5, 0.5, 0)],  # Gamma, X
               ecut=40, nblocks=nblocks,
@@ -55,49 +45,45 @@ reference = pytest.approx([-9.253, 5.442, 2.389, 0.403, 0.000,
 
 @pytest.mark.response
 @pytest.mark.slow
-@pytest.mark.parametrize('si', generate_si_systems())
-@pytest.mark.parametrize('symm', [{},
-                                  'off',
-                                  {'time_reversal': False},
-                                  {'point_group': False}])
+@pytest.mark.parametrize('si', [0, 1])
+@pytest.mark.parametrize('symm', ['all', 'no', 'tr', 'pg'])
 @pytest.mark.parametrize('nblocks',
                          [x for x in [1, 2, 4, 8] if x <= world.size])
 def test_response_gwsi(in_tmp_dir, si, symm, nblocks, scalapack,
-                       needs_ase_master):
-    assert run(si, symm, nblocks) == reference
+                       needs_ase_master, gpw_files, gpaw_new):
+    if gpaw_new and world.size > 1:
+        pytest.skip('Hybrids not working in parallel with GPAW_NEW=1')
+    filename = gpw_files[f'si_gw_a{si}_{symm}']
+    assert run(filename, nblocks) == reference
 
 
 @pytest.mark.response
 @pytest.mark.ci
-@pytest.mark.parametrize('si', generate_si_systems())
-@pytest.mark.parametrize('symm', [{}])
+@pytest.mark.parametrize('si', [0, 1])
+@pytest.mark.parametrize('symm', ['all'])
 def test_small_response_gwsi(in_tmp_dir, si, symm, scalapack,
-                             needs_ase_master):
-    assert run(si, symm, 1) == reference
+                             needs_ase_master, gpw_files, gpaw_new):
+    if gpaw_new and world.size > 1:
+        pytest.skip('Hybrids not working in parallel with GPAW_NEW=1')
+    filename = gpw_files[f'si_gw_a{si}_{symm}']
+    assert run(filename, 1) == reference
 
 
 @pytest.mark.response
 @pytest.mark.ci
-def test_few_freq_response_gwsi(in_tmp_dir, scalapack, needs_ase_master):
+def test_few_freq_response_gwsi(in_tmp_dir, scalapack, needs_ase_master,
+                                gpw_files, gpaw_new):
+    if gpaw_new and world.size > 1:
+        pytest.skip('Hybrids not working in parallel with GPAW_NEW=1')
+
     if world.size > 1:
         nblocks = 2
     else:
         nblocks = 1
 
     # This test has very few frequencies and tests that the code doesn't crash.
-    atoms = bulk('Si', 'diamond', a=5.43)
-    atoms.calc = GPAW(mode=PW(250),
-                      eigensolver='rmm-diis',
-                      occupations=FermiDirac(0.01),
-                      kpts={'size': (2, 2, 2), 'gamma': True},
-                      convergence={'density': 1e-7},
-                      parallel={'domain': 1},
-                      txt='si.txt')
-    atoms.get_potential_energy()
-    scalapack = atoms.calc.wfs.bd.comm.size
-    atoms.calc.diagonalize_full_hamiltonian(nbands=8, scalapack=scalapack)
-    atoms.calc.write('si.gpw', mode='all')
-    gw = G0W0('si.gpw', 'gw_0.2',
+    filename = gpw_files['si_gw_a0_all']
+    gw = G0W0(filename, 'gw_0.2',
               nbands=8, integrate_gamma=0,
               kpts=[(0, 0, 0), (0.5, 0.5, 0)],  # Gamma, X
               ecut=40, nblocks=nblocks,
