@@ -16,7 +16,7 @@ reference_kn = [[0.69806561, 2.58472004, 2.58472066,
 @pytest.mark.response
 def test_hubbard_GW(in_tmp_dir, gpw_files, needs_ase_master):
     # This tests checks the actual numerical accuracy which is asserted below
-    gw = G0W0(gpw_files['ag_plusU_pw_wfs'], 'gw',
+    gw = G0W0(gpw_files['ag_plusU_pw'], 'gw',
               integrate_gamma=0,
               frequencies={'type': 'nonlinear',
                            'domega0': 0.1, 'omegamax': None},
