@@ -4,12 +4,12 @@ import numpy as np
 from ase import Atoms
 from gpaw import GPAW, PW
 from gpaw.mpi import world
-from gpaw.test import equal, findpeak
+from gpaw.test import findpeak
 from gpaw.utilities import compiled_with_sl
 from gpaw.response.df import DielectricFunction
 
 # Comparing the plasmon peaks found in bulk sodium for two different
-# atomic structures. Testing for idential plasmon peaks. Not using
+# atomic structures. Testing for identical plasmon peaks. Not using
 # physical sodium cell.
 
 
@@ -21,6 +21,11 @@ def test_response_na_plasmon(in_tmp_dir):
                cell=(a, a, a),
                pbc=True)
 
+    # parallel calculations must have domain = 1
+    parallel = {'band': 1}
+    if world.size > 1 and compiled_with_sl():
+        parallel.update({'domain': 1})
+
     # Expanding along x-direction
     a2 = Atoms('Na2',
                scaled_positions=[[0, 0.1, 0], [0.5, 0.1, 0]],
@@ -28,15 +33,15 @@ def test_response_na_plasmon(in_tmp_dir):
                pbc=True)
 
     a1.calc = GPAW(mode=PW(250),
-                   kpts={'size': (8, 8, 8), 'gamma': True},
-                   parallel={'band': 1},
+                   kpts={'size': (4, 4, 4), 'gamma': True},
+                   parallel=parallel,
                    # txt='small.txt',
                    )
 
     # Kpoint sampling should be halved in the expanded direction.
     a2.calc = GPAW(mode=PW(250),
-                   kpts={'size': (4, 8, 8), 'gamma': True},
-                   parallel={'band': 1},
+                   kpts={'size': (2, 4, 4), 'gamma': True},
+                   parallel=parallel,
                    # txt='large.txt',
                    )
 
@@ -69,7 +74,14 @@ def test_response_na_plasmon(in_tmp_dir):
     dfs3 = []
     dfs4 = []
     dfs5 = []
-    for kwargs in settings:
+
+    # list of intensities to compare against. Intensity values matched
+    # to 10-3 w/ higher tol. Speeding up test degraded the agreement to 10-2
+    # Added additional intensity difference check test with tol 10-3
+    I_diffs = {'x': [0.008999, 0.007558, 0.008999, 0.007558, 0.006101],
+               'y': [0.004063, 0.004063, 0.004063, 0.004063, 0.004063],
+               'z': [0.004063, 0.005689, 0.004244, 0.005689, 0.005689]}
+    for idx, kwargs in enumerate(settings):
         df1 = DielectricFunction('gs_Na_small.gpw',
                                  ecut=40,
                                  rate=0.001,
@@ -95,22 +107,34 @@ def test_response_na_plasmon(in_tmp_dir):
         dfs4.append(df1NLFCz)
         dfs5.append(df1LFCz)
 
-        # Compare plasmon frequencies and intensities
+        # Compare plasmon frequencies and intensities: x, y, z
+        # x values
         w_w = df1.wd.omega_w
         w1, I1 = findpeak(w_w, -(1. / df1LFCx).imag)
         w2, I2 = findpeak(w_w, -(1. / df2LFCx).imag)
-        equal(w1, w2, 1e-2)
-        equal(I1, I2, 1e-3)
+        I_diff = abs(I1 - I2)
+        # test that the frequency for 2 settings are aprx equal
+        assert w1 == pytest.approx(w2, abs=1e-2)
+        # test that the intensity difference is within some tol
+        assert I_diff == pytest.approx(I_diffs['x'][idx], abs=5e-3)
+        # test that the intensities are aprx equal
+        assert I1 == pytest.approx(I2, abs=1e-2)
 
+        # y values
         w1, I1 = findpeak(w_w, -(1. / df1LFCy).imag)
         w2, I2 = findpeak(w_w, -(1. / df2LFCy).imag)
-        equal(w1, w2, 1e-2)
-        equal(I1, I2, 1e-3)
+        I_diff = abs(I1 - I2)
+        assert w1 == pytest.approx(w2, abs=1e-2)
+        assert I_diff == pytest.approx(I_diffs['y'][idx], abs=5e-3)
+        assert I1 == pytest.approx(I2, abs=1e-2)
 
+        # z values
         w1, I1 = findpeak(w_w, -(1. / df1LFCz).imag)
         w2, I2 = findpeak(w_w, -(1. / df2LFCz).imag)
-        equal(w1, w2, 1e-2)
-        equal(I1, I2, 1e-3)
+        I_diff = abs(I1 - I2)
+        assert w1 == pytest.approx(w2, abs=1e-2)
+        assert I_diff == pytest.approx(I_diffs['z'][idx], abs=5e-3)
+        assert I1 == pytest.approx(I2, abs=1e-2)
 
     # Check for self-consistency
     for i, dfs in enumerate([dfs0, dfs1, dfs2, dfs3, dfs4, dfs5]):
@@ -118,7 +142,7 @@ def test_response_na_plasmon(in_tmp_dir):
             df = dfs.pop()
             for df2 in dfs:
                 try:
-                    assert np.max(np.abs((df - df2) / df)) < 1e-3
+                    assert np.max(np.abs((df - df2) / df)) < 2e-3
                 except AssertionError:
                     print(np.max(np.abs((df - df2) / df)))
                     raise AssertionError
