@@ -15,7 +15,7 @@ from gpaw.response.symmetry import PWSymmetryAnalyzer
 
 from gpaw.test.response.test_chiks import (generate_system_s, generate_qrel_q,
                                            get_q_c, generate_nblocks_n)
-from gpaw.test.conftest import response_band_cutoff
+from gpaw.test.gpwfile import response_band_cutoff
 
 pytestmark = pytest.mark.skipif(world.size == 1, reason='world.size == 1')
 
@@ -43,7 +43,7 @@ def test_parallel_extract_kptdata(in_tmp_dir, gpw_files,
     context = ResponseContext()
     serial_gs = ResponseGroundStateAdapter.from_gpw_file(
         gpw_files[wfs], context)
-    
+
     # Initialize parallel ground state adapter
     calc = GPAW(gpw_files[wfs], parallel=dict(domain=1))
     nbands = response_band_cutoff[wfs]
@@ -112,7 +112,7 @@ def initialize_integral(extractor, context, q_c):
     # Initialize symmetry analyzer
     gs = extractor.gs
     qpd = SingleQPWDescriptor.from_q(q_c, 1e-3, gs.gd)
-    analyzer = PWSymmetryAnalyzer(gs.kd, qpd, context)
+    analyzer = PWSymmetryAnalyzer(gs.kpoints, qpd, context)
 
     return KPointPairPointIntegral(extractor, analyzer)
 
