@@ -79,9 +79,10 @@ def test_old_vs_new_spherical_kernel():
     """Test explicitely hard coded implementation against generic
     implementation.
     """
+    rng = np.random.RandomState(42)
     for n in range(3):
-        R = np.random.rand(100) * 10
-        r = np.random.rand(100) * 10
+        R = rng.random(100) * 10
+        r = rng.random(100) * 10
         params = (n, 0.11, R, r)
         new, old = phi(*params), phiold(*params)
         print(old, new, abs(old - new).max())
