@@ -1,7 +1,6 @@
 import pytest
 from gpaw import GPAW, restart
 from gpaw.cluster import Cluster
-from gpaw.test import equal
 from ase.build import molecule
 from ase.units import mol, kcal
 from gpaw.solvation import SolvationGPAW, get_HW14_water_kwargs
@@ -53,8 +52,8 @@ def test_solvation_water_water(H2O, parameters):
     DGSol = (Ewater - Evac) / (kcal / mol)
     print('Delta Gsol: %s kcal / mol' % DGSol)
 
-    equal(DGSol, -6.3, 2.)
-    equal(Ewater, Eelwater + Esurfwater, 1e-14)
+    assert DGSol == pytest.approx(-6.3, abs=2.)
+    assert Ewater == pytest.approx(Eelwater + Esurfwater, abs=1e-14)
 
 
 def test_read(H2O, in_tmp_dir):
