@@ -1,6 +1,5 @@
 from gpaw.tddft import TDDFT
 from gpaw.tddft.ehrenfest import EhrenfestVelocityVerlet
-from gpaw.test import equal
 import pytest
 
 
@@ -21,5 +20,5 @@ def test_tddft_ehrenfest_nacl(in_tmp_dir, gpw_files):
         r = evv.x[1][2] - evv.x[0][2]
         print('E = ', [i + 1, r, evv.Etot, evv.Ekin, evv.e_coulomb])
 
-    equal(r, 7.558883144, 1e-6)
-    equal(evv.Etot, -0.10359175317017391, 1e-4)
+    assert r == pytest.approx(7.558883144, abs=1e-6)
+    assert evv.Etot == pytest.approx(-0.10359175317017391, abs=1e-4)
