@@ -5,7 +5,7 @@
 
 from ase import Atoms
 from gpaw import GPAW, FermiDirac, MixerSum
-from gpaw.test import equal
+import pytest
 
 
 def test_fermisplit(in_tmp_dir):
@@ -37,10 +37,10 @@ def test_fermisplit(in_tmp_dir):
     ef4 = readtest.get_fermi_levels()
 
     # These values should be identic
-    equal(ef1, ef2, 1e-9)
-    equal(efsplit1, efsplit2, 1e-9)
-    equal(ef3.mean(), ef1, 1e-9)
-    equal(ef3.mean(), ef2, 1e-9)
-    equal(ef3.mean(), ef4.mean(), 1e-9)
-    equal(ef3[0] - ef3[1], ef4[0] - ef4[1], 1e-9)
-    equal(efsplit1, ef4[0] - ef4[1], 1e-9)
+    assert ef1 == pytest.approx(ef2, abs=1e-9)
+    assert efsplit1 == pytest.approx(efsplit2, abs=1e-9)
+    assert ef3.mean() == pytest.approx(ef1, abs=1e-9)
+    assert ef3.mean() == pytest.approx(ef2, abs=1e-9)
+    assert ef3.mean() == pytest.approx(ef4.mean(), abs=1e-9)
+    assert ef3[0] - ef3[1] == pytest.approx(ef4[0] - ef4[1], abs=1e-9)
+    assert efsplit1 == pytest.approx(ef4[0] - ef4[1], abs=1e-9)
