@@ -2,7 +2,7 @@ from ase.build import molecule
 from ase.parallel import parprint
 from gpaw import GPAW
 from gpaw.cluster import Cluster
-from gpaw.test import equal
+import pytest
 
 
 def test_fixocc():
@@ -34,7 +34,7 @@ def test_fixocc():
         H2.calc = c
         E_fo = H2.get_potential_energy()
         parprint(E_zk, E_fo)
-        equal(E_zk, E_fo, 1.e-10)
+        assert E_zk == pytest.approx(E_fo, abs=1.e-10)
 
     if 1:
         # test spin-paired vs spin-polarized
@@ -49,4 +49,4 @@ def test_fixocc():
         H2.calc = c
         E_sp = H2.get_potential_energy()
         parprint(E_ns, E_sp)
-        equal(E_ns, E_sp, 1.e-6)
+        assert E_ns == pytest.approx(E_sp, abs=1.e-6)
