@@ -1,10 +1,11 @@
-from gpaw import GPAW
-from gpaw import PW
-from gpaw import FermiDirac
+import pytest
 from ase.lattice.hexagonal import Graphene
 from ase.parallel import parprint
 
+from gpaw import GPAW, PW, FermiDirac
 
+
+@pytest.mark.legacy
 def test_kpt_refine():
     system = Graphene(symbol='C',
                       latticeconstant={'a': 2.467710, 'c': 1.0},
