@@ -5,7 +5,6 @@ from gpaw import GPAW
 from gpaw.cluster import Cluster
 from gpaw.analyse.hirshfeld import HirshfeldDensity, HirshfeldPartitioning
 from gpaw.analyse.wignerseitz import WignerSeitz
-from gpaw.test import equal
 import pytest
 
 
@@ -40,15 +39,17 @@ def test_utilities_partitioning(in_tmp_dir):
                     if gridrefinement < 4:
                         # The highest level of gridrefinement gets wrong
                         # electron numbers
-                        equal(gd.integrate(full), result, 1.e-8)
+                        assert gd.integrate(full) == pytest.approx(result,
+                                                                   abs=1.e-8)
                     else:
-                        equal(gd.integrate(full), result, 1.e-4)
+                        assert gd.integrate(full) == pytest.approx(result,
+                                                                   abs=1.e-4)
 
             hp = HirshfeldPartitioning(calc)
             vr = hp.get_effective_volume_ratios()
             parprint('Hirshfeld:', vr)
             if len(lastres):
-                equal(vr, lastres.pop(0), 1.e-10)
+                assert vr == pytest.approx(lastres.pop(0), abs=1.e-10)
             results.append(vr)
 
         # Wigner-Seitz ----------------------------------------
@@ -59,7 +60,7 @@ def test_utilities_partitioning(in_tmp_dir):
             vr = ws.get_effective_volume_ratios()
             parprint('Wigner-Seitz:', vr)
             if len(lastres):
-                equal(vr, lastres.pop(0), 1.e-10)
+                assert vr == pytest.approx(lastres.pop(0), abs=1.e-10)
             results.append(vr)
 
         return results
