@@ -1,7 +1,10 @@
-from gpaw import GPAW, PW
+import pytest
 from ase.lattice.compounds import L1_2
 
+from gpaw import GPAW, PW
 
+
+@pytest.mark.later
 def test_xc_qna_band(in_tmp_dir):
     """Cu3Au"""
     ecut = 300
