@@ -1,8 +1,7 @@
 import pytest
-from ase.lattice.cubic import BodyCenteredCubic
+from ase.atoms import Atoms
 
 from gpaw import GPAW, PW
-from gpaw.test import equal
 
 
 @pytest.mark.later
@@ -10,19 +9,15 @@ def test_xc_qna_spinpol(in_tmp_dir):
     QNA = {'alpha': 2.0,
            'name': 'QNA',
            'orbital_dependent': False,
-           'parameters': {'Fe': (0.1485, 0.005)},
+           'parameters': {'H': (0.1485, 0.005)},
            'setup_name': 'PBE',
            'type': 'qna-gga'}
 
-    atoms = BodyCenteredCubic(symbol='Fe',
-                              latticeconstant=2.854,
-                              pbc=(1, 1, 1))
-
-    atoms.set_initial_magnetic_moments([2, 2])
+    atoms = Atoms('H', pbc=True, cell=[5, 5, 5])
+    atoms.set_initial_magnetic_moments([1])
 
     calc = GPAW(mode=PW(400),
-                kpts=(3, 3, 3),
-                experimental={'niter_fixdensity': 2},
+                kpts=(1, 1, 1),
                 xc=QNA,
                 parallel={'domain': 1},
                 txt='qna_spinpol.txt')
@@ -32,5 +27,4 @@ def test_xc_qna_spinpol(in_tmp_dir):
     magmoms = atoms.get_magnetic_moments()
 
     tol = 0.003
-    equal(2.252, magmoms[0], tol)
-    equal(2.252, magmoms[1], tol)
+    assert 0.25374 == pytest.approx(magmoms[0], abs=tol)
