@@ -12,16 +12,20 @@ http://www.netlib.org/blacs
 and
 http://www.netlib.org/scalapack
 """
-
+import numpy as np
 
 import _gpaw
 
 switch_lu = {'U': 'L', 'L': 'U'}
+switch_lr = {'L': 'R', 'R': 'L'}
 
 
-def scalapack_tri2full(desc, array):
+def scalapack_tri2full(desc, array, conj=True):
     """Write lower triangular part into upper triangular part of matrix.
 
+    If conj == True, the lower triangular part is the complex conjugate
+    of the upper triangular part.
+
     This function is a frightful hack, but we can improve the
     implementation later."""
 
@@ -33,7 +37,8 @@ def scalapack_tri2full(desc, array):
     # Now transpose tmp_mm adding the result to the original matrix:
     pblas_tran(alpha=1.0, a_MN=buf,
                beta=1.0, c_NM=array,
-               desca=desc, descc=desc)
+               desca=desc, descc=desc,
+               conj=conj)
 
 
 def scalapack_zero(desca, a, uplo, ia=1, ja=1):
@@ -326,64 +331,138 @@ def scalapack_inverse(desca, a, uplo):
 
 
 def scalapack_solve(desca, descb, a, b):
-    """Perform general matrix solution to Ax=b. Result will be replaces with b.
-       Equivalent to numpy.linalg.solve(a, b.T.conjugate()).T.conjugate()
+    """General matrix solve.
 
+    Solve X from A*X = B. The array b will be replaced with the result.
+
+    This function works on the transposed form. The equivalent
+    non-distributed operation is numpy.linalg.solve(a.T, b.T).T.
+
+    This function executes the following scalapack routine:
+    * pzgesv if matrices are complex
+    * pdgesv if matrices are real
     """
     desca.checkassert(a)
     descb.checkassert(b)
-    # only symmetric matrices
-    assert desca.gshape[0] == desca.gshape[1]
-    # valid equation
-    assert desca.gshape[1] == descb.gshape[1]
+    assert desca.gshape[0] == desca.gshape[1], 'A not a square matrix'
+    assert desca.bshape[0] == desca.bshape[1], 'A not having square blocks'
+    assert desca.gshape[1] == descb.gshape[1], 'B shape not compatible with A'
+    assert desca.bshape[1] == descb.bshape[1], 'B blocks not compatible with A'
 
     if not desca.blacsgrid.is_active():
         return
-    info = _gpaw.scalapack_solve(a.T, desca.asarray(), b.T, descb.asarray())
+    info = _gpaw.scalapack_solve(a, desca.asarray(), b, descb.asarray())
     if info != 0:
         raise RuntimeError('scalapack_solve error: %d' % info)
 
 
-def pblas_tran(alpha, a_MN, beta, c_NM, desca, descc):
-    """C <- beta C + alpha A.T.
+def pblas_tran(alpha, a_MN, beta, c_NM, desca, descc, conj=True):
+    """Matrix transpose.
 
-    See also pdtran from PBLAS."""
+    C <- alpha*A.H + beta*C  if conj == True
+    C <- alpha*A.T + beta*C  if conj == False
+
+    This function executes the following PBLAS routine:
+    * pztranc if matrices are complex and conj == True
+    * pztranu if matrices are complex and conj == False
+    * pdtran  if matrices are real
+    """
     desca.checkassert(a_MN)
     descc.checkassert(c_NM)
     M, N = desca.gshape
     assert N, M == descc.gshape
     _gpaw.pblas_tran(N, M, alpha, a_MN, beta, c_NM,
-                     desca.asarray(), descc.asarray())
+                     desca.asarray(), descc.asarray(),
+                     conj)
 
 
-def pblas_hemm(alpha, a_MK, b_KN, beta, c_MN, desca, descb, descc,
-               side='L', uplo='L'):
-    # Hermitean matrix multiply, only lower or upper diagonal of a_MK
-    # is used. By default, C = beta*C + alpha*A*B
-    # Executes PBLAS method pzhemm for complex and pdsymm for real matrices.
-    desca.checkassert(a_MK)
-    descb.checkassert(b_KN)
+def _pblas_hemm_symm(alpha, a_MM, b_MN, beta, c_MN, desca, descb, descc,
+                     side, uplo, hemm):
+    """Hermitian or symmetric matrix-matrix product.
+
+    Do not call this function directly but
+    use :func:`pblas_hemm` or :func:`pblas_symm` instead.
+
+    C <- alpha*A*B + beta*C  if side == 'L'
+    C <- alpha*B*A + beta*C  if side == 'R'
+
+    Only lower or upper diagonal of a_MM is used.
+
+    This function executes the following PBLAS routine:
+    * pzhemm if matrices are complex and hemm == True
+    * pzsymm if matrices are complex and hemm == False
+    * pdsymm if matrices are real
+    """
+    # Note: if side == 'R', then a_MM matrix is actually size of a_NN
+    desca.checkassert(a_MM)
+    descb.checkassert(b_MN)
     descc.checkassert(c_MN)
-    assert side in ['R', 'L'] and uplo in ['L', 'U']
-    M, Ka = desca.gshape
-    Kb, N = descb.gshape
-    if side == 'R':
-        Kb, N = N, Kb
+    assert side in ['L', 'R'] and uplo in ['L', 'U']
+    Ma, Ma2 = desca.gshape
+    assert Ma == Ma2, 'A not square matrix'
+    Mb, Nb = descb.gshape
+    if side == 'L':
+        assert Mb == Ma
+    else:
+        assert Nb == Ma
+    M, N = descc.gshape
+    assert M == Mb
+    assert N == Nb
 
     if not desca.blacsgrid.is_active():
         return
-    fortran_side = {'L': 'R', 'R': 'L'}
-    fortran_uplo = {'U': 'L', 'L': 'U'}
-    if side == 'R':
-        M, N = N, M
+    _gpaw.pblas_hemm_symm(switch_lr[side], switch_lu[uplo],
+                          N, M, alpha, a_MM, b_MN, beta, c_MN,
+                          desca.asarray(), descb.asarray(), descc.asarray(),
+                          hemm)
 
-    _gpaw.pblas_hemm(fortran_side[side], fortran_uplo[uplo],
-                     N, M, alpha, a_MK.T, b_KN.T, beta, c_MN.T,
-                     desca.asarray(), descb.asarray(), descc.asarray())
+
+def pblas_hemm(alpha, a_MM, b_MN, beta, c_MN, desca, descb, descc,
+               side='L', uplo='L'):
+    """Hermitian matrix-matrix product.
+
+    C <- alpha*A*B + beta*C  if side == 'L'
+    C <- alpha*B*A + beta*C  if side == 'R'
+
+    Only lower or upper diagonal of a_MM is used.
+
+    This function executes the following PBLAS routine:
+    * pzhemm if matrices are complex
+    * pdsymm if matrices are real
+    """
+    return _pblas_hemm_symm(alpha, a_MM, b_MN, beta, c_MN,
+                            desca, descb, descc,
+                            side, uplo, hemm=True)
+
+
+def pblas_symm(alpha, a_MM, b_MN, beta, c_MN, desca, descb, descc,
+               side='L', uplo='L'):
+    """Symmetric matrix-matrix product.
+
+    C <- alpha*A*B + beta*C  if side == 'L'
+    C <- alpha*B*A + beta*C  if side == 'R'
+
+    Only lower or upper diagonal of a_MM is used.
+
+    This function executes the following PBLAS routine:
+    * pzsymm if matrices are complex
+    * pdsymm if matrices are real
+    """
+    return _pblas_hemm_symm(alpha, a_MM, b_MN, beta, c_MN,
+                            desca, descb, descc,
+                            side, uplo, hemm=False)
 
 
 def pblas_gemm(alpha, a_MK, b_KN, beta, c_MN, desca, descb, descc,
                transa='N', transb='N'):
+    """General matrix-matrix product.
+
+    C <- alpha*A*B + beta*C
+
+    This function executes the following PBLAS routine:
+    * pzgemm if matrices are complex
+    * pdgemm if matrices are real
+    """
     desca.checkassert(a_MK)
     descb.checkassert(b_KN)
     descc.checkassert(c_MN)
@@ -391,9 +470,9 @@ def pblas_gemm(alpha, a_MK, b_KN, beta, c_MN, desca, descb, descc,
     M, Ka = desca.gshape
     Kb, N = descb.gshape
 
-    if transa == 'T':
+    if transa in ['T', 'C']:
         M, Ka = Ka, M
-    if transb == 'T':
+    if transb in ['T', 'C']:
         Kb, N = N, Kb
     Mc, Nc = descc.gshape
 
@@ -401,38 +480,9 @@ def pblas_gemm(alpha, a_MK, b_KN, beta, c_MN, desca, descb, descc,
     assert M == Mc
     assert N == Nc
 
-    # trans = transa + transb
-
-    """
-    if transb == 'N':
-        assert desca.gshape[1] == descb.gshape[0]
-        assert desca.gshape[0] == descc.gshape[0]
-        assert descb.gshape[1] == descc.gshape[1]
-    if transb == 'T':
-        N, Kb = Kb, N
-        #assert desca.gshape[1] == descb.gshape[1]
-        assert desca.gshape[0] == descc.gshape[0]
-        assert descb.gshape[0] == descc.gshape[1]
-
-    if trans == 'NN':
-        assert desca.gshape[1] == descb.gshape[0]
-        assert desca.gshape[0] == descc.gshape[0]
-        assert descb.gshape[1] == descc.gshape[1]
-    elif transa == 'T':
-        M, Ka = Ka, M
-        assert desca.gshape[1] == descc.gshape[0]
-    if transb == 'N':
-        assert descb.gshape[1] == descc.gshape[1]
-    elif transb == 'T':
-        assert descb.gshape[1] == descc.gshape[1]
-    assert Ka == Kb
-    #assert transa == 'N' # XXX remember to implement 'T'
-    _gpaw.pblas_gemm(N, M, Ka, alpha, b_KN.T, a_MK.T, beta, c_MN.T,
-    """
-    # assert transa == 'N' # XXX remember to implement 'T'
     if not desca.blacsgrid.is_active():
         return
-    _gpaw.pblas_gemm(N, M, Ka, alpha, b_KN.T, a_MK.T, beta, c_MN.T,
+    _gpaw.pblas_gemm(N, M, Ka, alpha, b_KN, a_MK, beta, c_MN,
                      descb.asarray(), desca.asarray(), descc.asarray(),
                      transb, transa)
 
@@ -445,38 +495,65 @@ def pblas_simple_gemm(desca, descb, descc, a_MK, b_KN, c_MN,
                transa, transb)
 
 
-def pblas_simple_hemm(desca, descb, descc, a_MK, b_KN, c_MN,
+def pblas_simple_hemm(desca, descb, descc, a_MM, b_MN, c_MN,
                       side='L', uplo='L'):
     alpha = 1.0
     beta = 0.0
-    pblas_hemm(alpha, a_MK, b_KN, beta, c_MN, desca, descb, descc, side, uplo)
+    pblas_hemm(alpha, a_MM, b_MN, beta, c_MN, desca, descb, descc, side, uplo)
 
 
-def pblas_gemv(alpha, a, x, beta, y, desca, descx, descy,
-               transa='T'):
-    desca.checkassert(a)
-    descx.checkassert(x)
-    descy.checkassert(y)
+def pblas_simple_symm(desca, descb, descc, a_MM, b_MN, c_MN,
+                      side='L', uplo='L'):
+    alpha = 1.0
+    beta = 0.0
+    pblas_symm(alpha, a_MM, b_MN, beta, c_MN, desca, descb, descc, side, uplo)
+
+
+def pblas_gemv(alpha, a_MN, x_N, beta, y_M, desca, descx, descy,
+               transa='N'):
+    """General matrix-vector product.
+
+    y <- alpha*A*x + beta*y
+
+    This function executes the following PBLAS routine:
+    * pzgemv if matrices are complex
+    * pdgemv if matrices are real
+    """
+    desca.checkassert(a_MN)
+    descx.checkassert(x_N)
+    descy.checkassert(y_M)
+    assert transa in ['N', 'T', 'C']
     M, N = desca.gshape
-    # XXX transa = 'N' not implemented
-    assert transa in ['T', 'C']
-    assert desca.gshape[0] == descy.gshape[0]
-    assert desca.gshape[1] == descx.gshape[0]
-    assert descx.gshape[1] == descy.gshape[1]
+    Nx, Ox = descx.gshape
+    My, Oy = descy.gshape
+    assert Ox == 1
+    assert Oy == 1
+    if transa == 'N':
+        assert Nx == N
+        assert My == M
+    else:
+        assert Nx == M
+        assert My == N
+
+    # Switch transposition and handle complex conjugation manually
+    if transa == 'C':
+        a_MN = np.ascontiguousarray(a_MN.conj())
+    switch_ntc = {'N': 'T', 'T': 'N', 'C': 'N'}
+
     if not desca.blacsgrid.is_active():
         return
     _gpaw.pblas_gemv(N, M, alpha,
-                     a, x, beta, y,
+                     a_MN, x_N, beta, y_M,
                      desca.asarray(),
                      descx.asarray(),
                      descy.asarray(),
-                     transa)
+                     switch_ntc[transa])
 
 
-def pblas_simple_gemv(desca, descx, descy, a, x, y):
+def pblas_simple_gemv(desca, descx, descy, a, x, y, transa='N'):
     alpha = 1.0
     beta = 0.0
-    pblas_gemv(alpha, a, x, beta, y, desca, descx, descy)
+    pblas_gemv(alpha, a, x, beta, y, desca, descx, descy, transa)
 
 
 def pblas_r2k(alpha, a_NK, b_NK, beta, c_NN, desca, descb, descc,
