@@ -182,7 +182,7 @@ class RPACalculator:
             p('Response function bands : %s' % nbands)
         p('Plane wave cutoffs (eV) :', end='')
         for e in ecut_i:
-            p(' {0:.3f}'.format(e * Hartree), end='')
+            p(f' {e * Hartree:.3f}', end='')
         p()
         p(self.coulomb.description())
         self.context.print('')
@@ -208,7 +208,7 @@ class RPACalculator:
                                   hilbert=False,
                                   ecut=ecutmax * Hartree)
 
-        self.blockcomm = chi0calc.integrator.blockcomm
+        self.blockcomm = chi0calc.chi0_body_calc.integrator.blockcomm
 
         energy_qi = []
         nq = len(energy_qi)
@@ -231,8 +231,8 @@ class RPACalculator:
             nG = qpd.ngmax
 
             # First not completely filled band:
-            m1 = chi0calc.nocc1
-            p('# %s  -  %s' % (len(energy_qi), ctime().split()[-2]))
+            m1 = self.gs.nocc1
+            p(f'# {len(energy_qi)}  -  {ctime().split()[-2]}')
             p('q = [%1.3f %1.3f %1.3f]' % tuple(q_c))
 
             energy_i = []
@@ -253,7 +253,7 @@ class RPACalculator:
                 energy_i.append(energy)
                 m1 = m2
 
-                a = 1 / chi0calc.integrator.kncomm.size
+                a = 1 / chi0calc.chi0_body_calc.integrator.kncomm.size
                 if ecut < ecutmax and a != 1.0:
                     # Chi0 will be summed again over chicomm, so we divide
                     # by its size:
@@ -272,7 +272,7 @@ class RPACalculator:
         p()
         p('Total correlation energy:')
         for e_cut, e in zip(ecut_i, e_i):
-            p('%6.0f:   %6.4f eV' % (e_cut * Hartree, e * Hartree))
+            p(f'{e_cut * Hartree:6.0f}:   {e * Hartree:6.4f} eV')
         p()
 
         if len(e_i) > 1:
@@ -290,8 +290,8 @@ class RPACalculator:
     def calculate_q_rpa(self, chi0calc, chi0_s,
                         m1, m2, gcut):
         chi0 = chi0_s[0]
-        chi0calc.update_chi0(chi0,
-                             m1, m2, spins=chi0calc.get_spins())
+        chi0calc.update_chi0(
+            chi0, m1, m2, spins=range(chi0calc.gs.nspins))
 
         self.context.print('E_c(q) = ', end='', flush=False)
 
