@@ -19,15 +19,6 @@ Here are all the lists that can be modified:
 * extra_objects
 * define_macros
 
-The following lists work like above, but are only linked when compiling
-the parallel interpreter:
-
-* mpi_libraries
-* mpi_library_dirs
-* mpi_include_dirs
-* mpi_runtime_library_dirs
-* mpi_define_macros
-
 To override use the form:
 
     libraries = ['somelib', 'otherlib']
@@ -40,10 +31,13 @@ To append use the form
 # flake8: noqa
 
 # compiler = 'gcc'
-# mpicompiler = 'mpicc'
-# mpilinker = 'mpicc'
 # platform_id = ''
 
+# MPI:
+mpi = True
+if mpi:
+    compiler = 'mpicc'
+
 # FFTW3:
 fftw = True
 if fftw:
@@ -60,7 +54,7 @@ if 0:
     elpadir = '/home/user/elpa'
     libraries += ['elpa']
     library_dirs += ['{}/lib'.format(elpadir)]
-    extra_link_args += ['-Wl,-rpath={}/lib'.format(elpadir)]
+    runtime_library_dirs += ['{}/lib'.format(elpadir)]
     include_dirs += ['{}/include/elpa-xxxx.xx.xxx'.format(elpadir)]
 
 # LibXC:
@@ -81,16 +75,19 @@ if 0:
     include_dirs += [xc + 'include']
     library_dirs += [xc + 'lib']
     # You can use rpath to avoid changing LD_LIBRARY_PATH:
-    extra_link_args += ['-Wl,-rpath={xc}/lib'.format(xc=xc)]
+    runtime_library_dirs += [xc + 'lib']
     if 'xc' not in libraries:
         libraries.append('xc')
 
+# Enable this, if your MPI doesn't support MPI_INPLACE
+if 0:
+    undef_macros.append('GPAW_MPI_INPLACE')
 
 # libvdwxc:
 if 0:
     libvdwxc = True
     path = '/home/user/libvdwxc'
-    extra_link_args += ['-Wl,-rpath=%s/lib' % path]
-    library_dirs += ['%s/lib' % path]
     include_dirs += ['%s/include' % path]
+    library_dirs += ['%s/lib' % path]
+    runtime_library_dirs += ['%s/lib' % path]
     libraries += ['vdwxc']
